
Since 2009, the world has been stuck
on a single narrative
around a coming global food crisis
and what we need to do to avoid it.
How do we feed
nine billion people by 2050?
Every conference, podcast
and dialogue around global food security
starts with this question
and goes on to answer it
by saying we need to produce
70 percent more food.
The 2050 narrative started to evolve
shortly after global food prices
hit all-time highs in 2008.
People were suffering and struggling,
governments and world leaders
needed to show us
that they were paying attention
and were working to solve it.
The thing is, 2050
is so far into the future
that we can&#39;t even relate to it,
and more importantly,
if we keep doing what we&#39;re doing,
it&#39;s going to hit us
a lot sooner than that.
I believe we need to ask
a different question.
The answer to that question
needs to be framed differently.
If we can reframe the old narrative
and replace it with new numbers
that tell us a more complete pictures,
numbers that everyone can understand
and relate to,
we can avoid the crisis altogether.
I was a commodities trader in my past life
and one of the things
that I learned trading
is that every market has a tipping point,
the point at which
change occurs so rapidly
that it impacts the world
and things change forever.
Think of the last financial crisis,
or the dot-com crash.
So here&#39;s my concern.
We could have a tipping point
in global food and agriculture
if surging demand
surpasses the agricultural system&#39;s
structural capacity to produce food.
This means at this point supply
can no longer keep up with demand
despite exploding prices,
unless we can commit
to some type of structural change.
This time around,
it won&#39;t be about stock markets and money.
It&#39;s about people.
People could starve
and governments may fall.
This question of at what point
does supply struggle
to keep up with surging demand
is one that started off as an interest
for me while I was trading
and became an absolute obsession.
It went from interest to obsession
when I realized through my research
how broken the system was
and how very little data was being used
to make such critical decisions.
That&#39;s the point I decided to walk away
from a career on Wall Street
and start an entrepreneurial journey
to start Gro Intelligence.
At Gro, we focus on bringing this data
and doing the work to make it actionable,
to empower decision-makers at every level.
But doing this work,
we also realized that the world,
not just world leaders,
but businesses and citizens
like every single person in this room,
lacked an actionable guide
on how we can avoid
a coming global food security crisis.
And so we built a model,
leveraging the petabytes
of data we sit on,
and we solved for the tipping point.
Now, no one knows
we&#39;ve been working on this problem
and this is the first time
that I&#39;m sharing what we discovered.
We discovered that the tipping point
is actually a decade from now.
We discovered that the world
will be short 214 trillion calories
by 2027.
The world is not in a position
to fill this gap.
Now, you&#39;ll notice
that the way I&#39;m framing this
is different from how I started,
and that&#39;s intentional, because until now
this problem has been

quantified using mass:
think kilograms, tons, hectograms,
whatever your unit of choice is in mass.
Why do we talk about food
in terms of weight?
Because it&#39;s easy.
We can look at a photograph
and determine tonnage on a ship
by using a simple pocket calculator.
We can weigh trucks,
airplanes and oxcarts.
But what we care about
in food is nutritional value.
Not all foods are created equal,
even if they weigh the same.
This I learned firsthand
when I moved from Ethiopia
to the US for university.
Upon my return back home,
my father, who was so excited to see me,
greeted me by asking why I was fat.
Now, turns out that eating
approximately the same amount of food
as I did in Ethiopia, but in America,
had actually lent
a certain fullness to my figure.
This is why we should care about calories,
not about mass.
It is calories which sustain us.
So 214 trillion calories
is a very large number,
and not even the most dedicated of us
think in the hundreds
of trillions of calories.
So let me break this down differently.
An alternative way to think about this
is to think about it in Big Macs.
214 trillion calories.
A single Big Mac has 563 calories.
That means the world will be short
379 billion Big Macs in 2027.
That is more Big Macs
than McDonald&#39;s has ever produced.
So how did we get
to these numbers in the first place?
They&#39;re not made up.
This map shows you
where the world was 40 years ago.
It shows you net calorie gaps
in every country in the world.
Now, simply put,
this is just calories
consumed in that country
minus calories produced
in that same country.
This is not a statement
on malnutrition or anything else.
It&#39;s simply saying how many calories
are consumed in a single year
minus how many are produced.
Blue countries are net calorie exporters,
or self-sufficient.
They have some in storage for a rainy day.
Red countries are net calorie importers.
The deeper, the brighter the red,
the more you&#39;re importing.
40 years ago, such few countries
were net exporters of calories,
I could count them with one hand.
Most of the African continent,
Europe, most of Asia,
South America excluding Argentina,
were all net importers of calories.
And what&#39;s surprising is that China
used to actually be food self-sufficient.
India was a big net importer of calories.
40 years later, this is today.
You can see the drastic transformation
that&#39;s occurred in the world.
Brazil has emerged
as an agricultural powerhouse.
Europe is dominant in global agriculture.
India has actually flipped
from red to blue.
It&#39;s become food self-sufficient.
And China went from that light blue
to the brightest red
that you see on this map.
How did we get here? What happened?
So this chart shows you India and Africa.
Blue line is India, red line is Africa.
How is it that two regions
that started off so similarly
in such similar trajectories
take such different paths?
India had a green revolution.
Not a single African country
had a green revolution.
The net outcome?
India is food self-sufficient
and in the past decade
has actually been exporting calories.
The African continent now imports
over 300 trillion calories a year.
Then we add China, the green line.
Remember the switch
from the blue to the bright red?
What happened and when did it happen?
China seemed to be
on a very similar path to India
until the start of the 21st century,
where it suddenly flipped.
A young and growing population
combined with significant economic growth
made its mark with a big bang
and no one in the markets saw it coming.
This flip was everything
to global agricultural markets.
Luckily now, South America
was starting to boom
at the same time as China&#39;s rise,
and so therefore, supply and demand
were still somewhat balanced.
So the question becomes,
where do we go from here?
Oddly enough,
it&#39;s not a new story,
except this time
it&#39;s not just a story of China.
It&#39;s a continuation of China,
an amplification of Africa
and a paradigm shift in India.
By 2023,
Africa&#39;s population is forecasted
to overtake that of India&#39;s and China&#39;s.
By 2023, these three regions combined
will make up over half
the world&#39;s population.
This crossover point starts to present
really interesting challenges
for global food security.
And a few years later,
we&#39;re hit hard with that reality.
What does the world look like in 10 years?
So far, as I mentioned,
India has been food self-sufficient.
Most forecasters predict
that this will continue.
We disagree.
India will soon become
a net importer of calories.
This will be driven both by the fact
that demand is growing
from a population growth standpoint
plus economic growth.
It will be driven by both.
And even if you have
optimistic assumptions
around production growth,
it will make that slight flip.
That slight flip
can have huge implications.
Next, Africa will continue
to be a net importer of calories,
again driven by population growth
and economic growth.
This is again assuming optimistic
production growth assumptions.
Then China,
where population is flattening out,
calorie consumption will explode
because the types of calories consumed
are also starting to be
higher-calorie-content foods.
And so therefore,
these three regions combined
start to present a really interesting
challenge for the world.
Until now, countries with calorie deficits
have been able to meet these deficits
by importing from surplus regions.
By surplus regions, I&#39;m talking about
North America, South America and Europe.
This line chart over here shows you
the growth and the projected growth
over the next decade of production
from North America,
South America and Europe.
What it doesn&#39;t show you
is that most of this growth is actually
going to come from South America.
And most of this growth
is going to come
at the huge cost of deforestation.
And so when you look
at the combined demand increase
coming from India, China
and the African continent,
and look at it versus
the combined increase in production
coming from India,
China, the African continent,
North America, South America and Europe,
you are left with
a 214-trillion-calorie deficit,
one we can&#39;t produce.
And this, by the way, is actually assuming
we take all the extra calories
produced in North America,
South America and Europe
and export them solely
to India, China and Africa.
What I just presented to you
is a vision of an impossible world.
We can do something to change that.
We can change consumption patterns,
we can reduce food waste,
or we can make a bold commitment
to increasing yields exponentially.
Now, I&#39;m not going to go into discussing
changing consumption patterns
or reducing food waste,
because those conversations
have been going on for some time now.
Nothing has happened.
Nothing has happened
because those arguments
ask the surplus regions
to change their behavior
on behalf of deficit regions.
Waiting for others
to change their behavior
on your behalf, for your survival,
is a terrible idea.
It&#39;s unproductive.
So I&#39;d like to suggest an alternative
that comes from the red regions.
China, India, Africa.
China is constrained in terms
of how much more land it actually has
available for agriculture,
and it has massive
water resource availability issues.
So the answer really lies
in India and in Africa.
India has some upside
in terms of potential yield increases.
Now this is the gap
between its current yield
and the theoretical
maximum yield it can achieve.
It has some unfarmed
arable land remaining, but not much,
India is quite land-constrained.
Now, the African continent,
on the other hand,
has vast amounts of arable land remaining
and significant
upside potential in yields.
Somewhat simplified picture here,
but if you look at sub-Saharan
African yields in corn today,
they are where North American
yields were in 1940.
We don&#39;t have 70-plus years
to figure this out,
so it means we need to try something new
and we need to try something different.
The solution starts with reforms.
We need to reform and commercialize
the agricultural industries in Africa
and in India.
Now, by commercialization --
commercialization is not
about commercial farming alone.
Commercialization is about leveraging data
to craft better policies,
to improve infrastructure,
to lower the transportation costs
and to completely reform
banking and insurance industries.
Commercialization
is about taking agriculture
from too risky an endeavor
to one where fortunes can be made.
Commercialization
is not about just farmers.
Commercialization is about
the entire agricultural system.
But commercialization
also means confronting the fact
that we can no longer place
the burden of growth
on small-scale farmers alone,
and accepting that commercial farms
and the introduction of commercial farms
could provide certain economies of scale
that even small-scale
farmers can leverage.
It is not about small-scale farming
or commercial agriculture,
or big agriculture.
We can create the first successful models
of the coexistence and success
of small-scale farming
alongside commercial agriculture.
This is because, for the first time ever,
the most critical tool
for success in the industry --
data and knowledge --
is becoming cheaper by the day.
And very soon, it won&#39;t matter
how much money you have
or how big you are
to make optimal decisions
and maximize probability of success
in reaching your intended goal.
Companies like Gro are working
really hard to make this a reality.
So if we can commit
to this new, bold initiative,
to this new, bold change,
not only can we solve
the 214-trillion gap that I talked about,
but we can actually set the world
on a whole new path.
India can remain food self-sufficient
and Africa can emerge
as the world&#39;s next dark blue region.
The new question is,
how do we produce 214 trillion calories
to feed 8.3 billion people by 2027?
We have the solution.
We just need to act on it.
Thank you.

(Applause)

