
Cancer affects all of us --
especially the ones that come
back over and over again,
the highly invasive
and drug-resistant ones,
the ones that defy medical treatment,
even when we throw our best drugs at them.
Engineering at the molecular level,
working at the smallest of scales,
can provide exciting new ways
to fight the most aggressive
forms of cancer.
Cancer is a very clever disease.
There are some forms of cancer,
which, fortunately, we&#39;ve learned
how to address relatively well
with known and established
drugs and surgery.
But there are some forms of cancer
that don&#39;t respond to these approaches,
and the tumor survives or comes back,
even after an onslaught of drugs.
We can think of these
very aggressive forms of cancer
as kind of supervillains in a comic book.
They&#39;re clever, they&#39;re adaptable,
and they&#39;re very good at staying alive.
And, like most supervillains these days,
their superpowers come
from a genetic mutation.
The genes that are modified
inside these tumor cells
can enable and encode for new
and unimagined modes of survival,
allowing the cancer cell to live through
even our best chemotherapy treatments.
One example is a trick
in which a gene allows a cell,
even as the drug approaches the cell,
to push the drug out,
before the drug can have any effect.
Imagine -- the cell effectively
spits out the drug.
This is just one example
of the many genetic tricks
in the bag of our supervillain, cancer.
All due to mutant genes.
So, we have a supervillain
with incredible superpowers.
And we need a new and powerful
mode of attack.
Actually, we can turn off a gene.
The key is a set of molecules
known as siRNA.
siRNA are short sequences of genetic code
that guide a cell to block a certain gene.
Each siRNA molecule
can turn off a specific gene
inside the cell.
For many years since its discovery,
scientists have been very excited
about how we can apply
these gene blockers in medicine.
But, there is a problem.
siRNA works well inside the cell.
But if it gets exposed to the enzymes
that reside in our bloodstream
or our tissues,
it degrades within seconds.
It has to be packaged, protected
through its journey through the body
on its way to the final target
inside the cancer cell.
So, here&#39;s our strategy.
First, we&#39;ll dose the cancer cell
with siRNA, the gene blocker,
and silence those survival genes,
and then we&#39;ll whop it with a chemo drug.
But how do we carry that out?
Using molecular engineering,
we can actually design a superweapon
that can travel through the bloodstream.
It has to be tiny enough
to get through the bloodstream,
it&#39;s got to be small enough
to penetrate the tumor tissue,
and it&#39;s got to be tiny enough
to be taken up inside the cancer cell.
To do this job well,
it has to be about one one-hundredth
the size of a human hair.
Let&#39;s take a closer look
at how we can build this nanoparticle.
First, let&#39;s start
with the nanoparticle core.
It&#39;s a tiny capsule that contains
the chemotherapy drug.
This is the poison that will
actually end the tumor cell&#39;s life.
Around this core, we&#39;ll wrap a very thin,
nanometers-thin blanket of siRNA.
This is our gene blocker.
Because siRNA is strongly
negatively charged,
we can protect it
with a nice, protective layer
of positively charged polymer.
The two oppositely charged
molecules stick together
through charge attraction,
and that provides us
with a protective layer
that prevents the siRNA
from degrading in the bloodstream.
We&#39;re almost done.

(Laughter)

But there is one more big obstacle
we have to think about.
In fact, it may be the biggest
obstacle of all.
How do we deploy this superweapon?
I mean, every good weapon
needs to be targeted,
we have to target this superweapon
to the supervillain cells
that reside in the tumor.
But our bodies have a natural

immune-defense system:
cells that reside in the bloodstream
and pick out things that don&#39;t belong,
so that it can destroy or eliminate them.
And guess what? Our nanoparticle
is considered a foreign object.
We have to sneak our nanoparticle
past the tumor defense system.
We have to get it past this mechanism
of getting rid of the foreign object
by disguising it.
So we add one more
negatively charged layer
around this nanoparticle,
which serves two purposes.
First, this outer layer is one
of the naturally charged,
highly hydrated polysaccharides
that resides in our body.
It creates a cloud of water molecules
around the nanoparticle
that gives us an invisibility
cloaking effect.
This invisibility cloak allows
the nanoparticle
to travel through the bloodstream
long and far enough to reach the tumor,
without getting eliminated by the body.
Second, this layer contains molecules
which bind specifically to our tumor cell.
Once bound, the cancer cell
takes up the nanoparticle,
and now we have our nanoparticle
inside the cancer cell
and ready to deploy.
Alright! I feel the same way. Let&#39;s go!

(Applause)

The siRNA is deployed first.
It acts for hours,
giving enough time to silence
and block those survival genes.
We have now disabled
those genetic superpowers.
What remains is a cancer cell
with no special defenses.
Then, the chemotherapy drug
comes out of the core
and destroys the tumor cell
cleanly and efficiently.
With sufficient gene blockers,
we can address many
different kinds of mutations,
allowing the chance to sweep out tumors,
without leaving behind any bad guys.
So, how does our strategy work?
We&#39;ve tested these nanostructure
particles in animals
using a highly aggressive form
of triple-negative breast cancer.
This triple-negative breast cancer
exhibits the gene
that spits out cancer drug
as soon as it is delivered.
Usually, doxorubicin -- let&#39;s call
it &quot;dox&quot; -- is the cancer drug
that is the first line of treatment
for breast cancer.
So, we first treated our animals
with a dox core, dox only.
The tumor slowed their rate of growth,
but they still grew rapidly,
doubling in size
over a period of two weeks.
Then, we tried
our combination superweapon.
A nanolayer particle with siRNA
against the chemo pump,
plus, we have the dox in the core.
And look -- we found that not only
did the tumors stop growing,
they actually decreased in size
and were eliminated in some cases.
The tumors were actually regressing.

(Applause)

What&#39;s great about this approach
is that it can be personalized.
We can add many different layers of siRNA
to address different mutations
and tumor defense mechanisms.
And we can put different drugs
into the nanoparticle core.
As doctors learn how to test patients
and understand certain
tumor genetic types,
they can help us determine which patients
can benefit from this strategy
and which gene blockers we can use.
Ovarian cancer strikes
a special chord with me.
It is a very aggressive cancer,
in part because it&#39;s discovered
at very late stages,
when it&#39;s highly advanced
and there are a number
of genetic mutations.
After the first round of chemotherapy,
this cancer comes back
for 75 percent of patients.
And it usually comes back
in a drug-resistant form.
High-grade ovarian cancer
is one of the biggest
supervillains out there.
And we&#39;re now directing our superweapon
toward its defeat.
As a researcher,
I usually don&#39;t get to work with patients.
But I recently met a mother
who is an ovarian cancer survivor,
Mimi, and her daughter, Paige.
I was deeply inspired
by the optimism and strength
that both mother and daughter displayed
and by their story of courage and support.
At this event, we spoke
about the different technologies
directed at cancer.
And Mimi was in tears
as she explained how learning
about these efforts
gives her hope for future generations,
including her own daughter.
This really touched me.
It&#39;s not just about building
really elegant science.
It&#39;s about changing people&#39;s lives.
It&#39;s about understanding
the power of engineering
on the scale of molecules.
I know that as students like Paige
move forward in their careers,
they&#39;ll open new possibilities
in addressing some of the big
health problems in the world --
including ovarian cancer, neurological
disorders, infectious disease --
just as chemical engineering has
found a way to open doors for me,
and has provided a way of engineering
on the tiniest scale,
that of molecules,
to heal on the human scale.
Thank you.

(Applause)

