
When people think about cities,
they tend to think of certain things.
They think of buildings and streets
and skyscrapers, noisy cabs.
But when I think about cities,
I think about people.
Cities are fundamentally about people,
and where people go
and where people meet
are at the core of what makes a city work.
So even more important than buildings in a city
are the public spaces in between them.
And today, some of the most transformative
changes in cities
are happening in these public spaces.
So I believe that lively, enjoyable public spaces
are the key to planning a great city.
They are what makes it come alive.
But what makes a public space work?
What attracts people to successful public spaces,
and what is it about unsuccessful places
that keeps people away?
I thought, if I could answer those questions,
I could make a huge contribution to my city.
But one of the more wonky things about me
is that I am an animal behaviorist,
and I use those skills not to study animal behavior
but to study how people in cities
use city public spaces.
One of the first spaces that I studied
was this little vest pocket park called Paley Park
in midtown Manhattan.
This little space became a small phenomenon,
and because it had such a profound impact
on New Yorkers,
it made an enormous impression on me.
I studied this park very early on in my career
because it happened to have been built
by my stepfather,
so I knew that places like Paley Park
didn&#39;t happen by accident.
I saw firsthand that they required
incredible dedication
and enormous attention to detail.
But what was it about this space
that made it special and drew people to it?
Well, I would sit in the park and watch very carefully,
and first among other things
were the comfortable, movable chairs.
People would come in, find their own seat,
move it a bit, actually, and then stay a while,
and then interestingly,
people themselves attracted other people,
and ironically, I felt more peaceful
if there were other people around.
And it was green.

This little park provided what New Yorkers crave:
comfort and greenery.
But my question was,
why weren&#39;t there more places with greenery
and places to sit in the middle of the city
where you didn&#39;t feel alone,
or like a trespasser?
Unfortunately, that&#39;s not how cities
were being designed.
So here you see a familiar sight.
This is how plazas have been
designed for generations.
They have that stylish, Spartan look
that we often associate with modern architecture,
but it&#39;s not surprising that people
avoid spaces like this.
They not only look desolate,
they feel downright dangerous.
I mean, where would you sit here?
What would you do here?
But architects love them.
They are plinths for their creations.
They might tolerate a sculpture or two,
but that&#39;s about it.
And for developers, they are ideal.
There&#39;s nothing to water, nothing to maintain,
and no undesirable people to worry about.
But don&#39;t you think this is a waste?
For me, becoming a city planner
meant being able to truly change the city
that I lived in and loved.
I wanted to be able to create places
that would give you the feeling that you got
in Paley Park,
and not allow developers to
build bleak plazas like this.
But over the many years,
I have learned how hard it is
to create successful, meaningful,
enjoyable public spaces.
As I learned from my stepfather,
they certainly do not happen by accident,
especially in a city like New York,
where public space has to
be fought for to begin with,
and then for them to be successful,
somebody has to think very hard
about every detail.
Now, open spaces in cities are opportunities.
Yes, they are opportunities
for commercial investment,
but they are also opportunities for the common good
of the city,
and those two goals are often
not aligned with one another,
and therein lies the conflict.
The first opportunity I had to fight
for a great public open space was in the early 1980s,
when I was leading a team of planners
at a gigantic landfill called Battery Park City
in lower Manhattan on the Hudson River.
And this sandy wasteland had lain barren
for 10 years,
and we were told, unless we found a developer
in six months, it would go bankrupt.
So we came up with a radical,
almost insane idea.
Instead of building a park
as a complement to future development,
why don&#39;t we reverse that equation
and build a small but very high-quality
public open space first,
and see if that made a difference.
So we only could afford to build a two-block section
of what would become a mile-long esplanade,
so whatever we built had to be perfect.
So just to make sure, I insisted
that we build a mock-up
in wood, at scale, of the railing and the sea wall.
And when I sat down on that test bench
with sand still swirling all around me,
the railing hit exactly at eye level,
blocking my view and ruining my experience
at the water&#39;s edge.
So you see, details really do make a difference.
But design is not just how something looks,
it&#39;s how your body feels on that seat in that space,
and I believe that successful design always depends
on that very individual experience.
In this photo, everything looks very finished,
but that granite edge, those lights,
the back on that bench,
the trees in planting,
and the many different kinds of places to sit
were all little battles that turned this project
into a place that people wanted to be.
Now, this proved very valuable 20 years later
when Michael Bloomberg asked me to be
his planning commissioner
and put me in charge of shaping
the entire city of New York.
And he said to me on that very day,
he said that New York was projected
to grow from eight to nine million people.
And he asked me,
&quot;So where are you going to put
one million additional New Yorkers?&quot;
Well, I didn&#39;t have any idea.
Now, you know that New York does
place a high value on attracting immigrants,
so we were excited about the prospect of growth,
but honestly, where were we going to grow
in a city that was already built out to its edges
and surrounded by water?
How were we going to find housing
for that many new New Yorkers?
And if we couldn&#39;t spread out,
which was probably a good thing,
where could new housing go?
And what about cars?
Our city couldn&#39;t possibly handle any more cars.
So what were we going to do?
If we couldn&#39;t spread out, we had to go up.
And if we had to go up,
we had to go up in places
where you wouldn&#39;t need to own a car.

So that meant using one of our greatest assets:
our transit system.
But we had never before thought
of how we could make the most of it.
So here was the answer to our puzzle.
If we were to channel and redirect
all new development around transit,
we could actually handle that population increase,
we thought.
And so here was the plan,

what we really needed to do:
We needed to redo our zoning --
and zoning is the city planner&#39;s regulatory tool --
and basically reshape the entire city,
targeting where new development could go
and prohibiting any development at all
in our car-oriented,
suburban-style neighborhoods.
Well, this was an unbelievably ambitious idea,
ambitious because communities
had to approve those plans.
So how was I going to get this done?
By listening. So I began listening,
in fact, thousands of hours of listening
just to establish trust.
You know, communities can tell
whether or not you understand their neighborhoods.
It&#39;s not something you can just fake.
And so I began walking.
I can&#39;t tell you how many blocks I walked,
in sweltering summers, in freezing winters,
year after year,
just so I could get to understand
the DNA of each neighborhood
and know what each street felt like.
I became an incredibly geeky zoning expert,
finding ways that zoning could address
communities&#39; concerns.
So little by little, neighborhood by neighborhood,
block by block,
we began to set height limits
so that all new development
would be predictable and near transit.
Over the course of 12 years,
we were able to rezone
124 neighborhoods,
40 percent of the city,
12,500 blocks, so that now,
90 percent of all new development of New York
is within a 10-minute walk of a subway.
In other words, nobody in those new buildings
needs to own a car.
Well, those rezonings were exhausting
and enervating and important,
but rezoning was never my mission.
You can&#39;t see zoning and you can&#39;t feel zoning.
My mission was always to create
great public spaces.
So in the areas where we zoned
for significant development,
I was determined to create places
that would make a difference in people&#39;s lives.
Here you see what was
two miles of abandoned, degraded waterfront
in the neighborhoods of Greenpoint
and Williamsburg in Brooklyn,
impossible to get to and impossible to use.
Now the zoning here was massive,
so I felt an obligation to create
magnificent parks on these waterfronts,
and I spent an incredible amount of time
on every square inch of these plans.
I wanted to make sure that there were
tree-lined paths from the upland to the water,
that there were trees and plantings everywhere,
and, of course, lots and lots of places to sit.
Honestly, I had no idea how it would turn out.
I had to have faith.
But I put everything that I had studied and learned
into those plans.
And then it opened,
and I have to tell you, it was incredible.
People came from all over the city
to be in these parks.
I know they changed the lives
of the people who live there,
but they also changed New Yorkers&#39; whole image
of their city.
I often come down and watch people
get on this little ferry
that now runs between the boroughs,
and I can&#39;t tell you why,
but I&#39;m completely moved
by the fact that people are using it
as if it had always been there.
And here is a new park in lower Manhattan.
Now, the water&#39;s edge in lower Manhattan
was a complete mess before 9/11.
Wall Street was essentially landlocked
because you couldn&#39;t get anywhere near this edge.
And after 9/11, the city had very little control.
But I thought if we went
to the Lower Manhattan Development Corporation
and got money to reclaim this two miles
of degraded waterfront
that it would have an enormous effect
on the rebuilding of lower Manhattan.
And it did.
Lower Manhattan finally has a public waterfront
on all three sides.
I really love this park.
You know, railings have to be higher now,
so we put bar seating at the edge,
and you can get so close to the water
you&#39;re practically on it.
And see how the railing widens
and flattens out so you can lay down
your lunch or your laptop.
And I love when people come there
and look up and they say,
&quot;Wow, there&#39;s Brooklyn, and it&#39;s so close.&quot;
So what&#39;s the trick?
How do you turn a park
into a place that people want to be?
Well, it&#39;s up to you,
not as a city planner but as a human being.
You don&#39;t tap into your design expertise.
You tap into your humanity.
I mean, would you want to go there?
Would you want to stay there?
Can you see into it and out of it?
Are there other people there?
Does it seem green and friendly?
Can you find your very own seat?
Well now, all over New York City,
there are places where you can
find your very own seat.
Where there used to be parking spaces,
there are now pop-up cafes.
Where Broadway traffic used to run,
there are now tables and chairs.
Where 12 years ago, sidewalk
cafes were not allowed,
they are now everywhere.
But claiming these spaces for public use
was not simple,
and it&#39;s even harder to keep them that way.
So now I&#39;m going to tell you a story
about a very unusual park called the High Line.
The High Line was an elevated railway.

(Applause)

The High Line was an elevated railway
that ran through three neighborhoods
on Manhattan&#39;s West Side,
and when the train stopped running,
it became a self-seeded landscape,
a kind of a garden in the sky.
And when I saw it the first time,
honestly, when I went up on that old viaduct,
I fell in love the way you fall in love with a person,
honestly.
And when I was appointed,
saving the first two sections of the High Line
from demolition became my first priority
and my most important project.
I knew if there was a day that I didn&#39;t
worry about the High Line, it would come down.
And the High Line,
even though it is widely known now
and phenomenally popular,
it is the most contested public space in the city.
You might see a beautiful park,
but not everyone does.
You know, it&#39;s true, commercial interests
will always battle against public space.
You might say,
&quot;How wonderful it is that more than
four million people come from all over the world
to visit the High Line.&quot;

Well, a developer sees just one thing: customers.
Hey, why not take out those plantings
and have shops all along the High Line?
Wouldn&#39;t that be terrific
and won&#39;t it mean a lot more money for the city?
Well no, it would not be terrific.
It would be a mall, and not a park.

(Applause)

And you know what, it might mean
more money for the city,
but a city has to take the long view,
the view for the common good.
Most recently, the last section of the High Line,
the third section of the High Line,
the final section of the High Line,
has been pitted against development interests,
where some of the city&#39;s leading developers
are building more than 17 million square feet
at the Hudson Yards.
And they came to me and proposed
that they &quot;temporarily disassemble&quot;
that third and final section.
Perhaps the High Line didn&#39;t fit in
with their image of a gleaming city of skyscrapers
on a hill.
Perhaps it was just in their way.
But in any case, it took nine months
of nonstop daily negotiation
to finally get the signed agreement
to prohibit its demolition,
and that was only two years ago.
So you see, no matter how popular
and successful a public space may be,
it can never be taken for granted.
Public spaces always -- this is it saved --
public spaces always need vigilant champions,
not only to claim them at the outset for public use,
but to design them for the people that use them,
then to maintain them to ensure
that they are for everyone,
that they are not violated, invaded,
abandoned or ignored.
If there is any one lesson
that I have learned in my life as a city planner,
it is that public spaces have power.
It&#39;s not just the number of people using them,
it&#39;s the even greater number of people
who feel better about their city
just knowing that they are there.
Public space can change how you live in a city,
how you feel about a city,
whether you choose one city over another,
and public space is one of
the most important reasons
why you stay in a city.
I believe that a successful city
is like a fabulous party.
People stay because they are having a great time.
Thank you.

(Applause)

Thank you. 
(Applause)

