
Two twin domes,
two radically opposed design cultures.
One is made of thousands of steel parts,
the other of a single silk thread.
One is synthetic, the other organic.
One is imposed on the environment,
the other creates it.
One is designed for nature,
the other is designed by her.
Michelangelo said that
when he looked at raw marble,
he saw a figure struggling to be free.
The chisel was Michelangelo&#39;s only tool.
But living things are not chiseled.
They grow.
And in our smallest units of life,
our cells, we carry all the information
that&#39;s required for every other cell
to function and to replicate.
Tools also have consequences.
At least since the Industrial Revolution,
the world of design has been dominated
by the rigors of manufacturing
and mass production.
Assembly lines have dictated
a world made of parts,
framing the imagination
of designers and architects
who have been trained to think
about their objects as assemblies
of discrete parts with distinct functions.
But you don&#39;t find homogenous
material assemblies in nature.
Take human skin, for example.
Our facial skins are thin
with large pores.
Our back skins are thicker,
with small pores.
One acts mainly as filter,
the other mainly as barrier,

and yet it&#39;s the same skin:
no parts, no assemblies.
It&#39;s a system that gradually
varies its functionality
by varying elasticity.
So here this is a split screen
to represent my split world view,
the split personality of every designer
and architect operating today
between the chisel and the gene,
between machine and organism,
between assembly and growth,
between Henry Ford and Charles Darwin.
These two worldviews,
my left brain and right brain,
analysis and synthesis, will play out
on the two screens behind me.
My work, at its simplest level,
is about uniting these two worldviews,
moving away from assembly
and closer into growth.

You&#39;re probably asking yourselves:
Why now?
Why was this not possible 10
or even five years ago?
We live in a very special time in history,
a rare time,
a time when the confluence of four fields
is giving designers access to tools
we&#39;ve never had access to before.
These fields are computational design,
allowing us to design
complex forms with simple code;
additive manufacturing,
letting us produce parts
by adding material
rather than carving it out;
materials engineering, which lets us
design the behavior of materials
in high resolution;
and synthetic biology,
enabling us to design new biological
functionality by editing DNA.
And at the intersection
of these four fields,
my team and I create.
Please meet the minds and hands
of my students.
We design objects and products
and structures and tools across scales,
from the large-scale,
like this robotic arm
with an 80-foot diameter reach
with a vehicular base that will
one day soon print entire buildings,
to nanoscale graphics made entirely
of genetically engineered microorganisms
that glow in the dark.
Here we&#39;ve reimagined the mashrabiya,
an archetype of ancient
Arabic architecture,
and created a screen where
every aperture is uniquely sized
to shape the form of light and heat
moving through it.
In our next project,
we explore the possibility
of creating a cape and skirt --
this was for a Paris fashion show
with Iris van Herpen --
like a second skin
that are made of a single part,
stiff at the contours,
flexible around the waist.
Together with my long-term
3D printing collaborator Stratasys,
we 3D-printed this cape and skirt
with no seams between the cells,
and I&#39;ll show more objects like it.
This helmet combines
stiff and soft materials
in 20-micron resolution.
This is the resolution of a human hair.
It&#39;s also the resolution of a CT scanner.
That designers have access
to such high-resolution
analytic and synthetic tools,
enables to design products that fit
not only the shape of our bodies,
but also the physiological
makeup of our tissues.
Next, we designed an acoustic chair,
a chair that would be at once
structural, comfortable
and would also absorb sound.
Professor Carter, my collaborator, and I
turned to nature for inspiration,
and by designing this irregular
surface pattern,
it becomes sound-absorbent.
We printed its surface
out of 44 different properties,
varying in rigidity, opacity and color,
corresponding to pressure points
on the human body.
Its surface, as in nature,
varies its functionality
not by adding another material
or another assembly,
but by continuously and delicately
varying material property.
But is nature ideal?
Are there no parts in nature?
I wasn&#39;t raised
in a religious Jewish home,
but when I was young,
my grandmother used to tell me
stories from the Hebrew Bible,
and one of them stuck with me and came
to define much of what I care about.

As she recounts:
&quot;On the third day of Creation,
God commands the Earth
to grow a fruit-bearing fruit tree.&quot;
For this first fruit tree,
there was to be no differentiation
between trunk, branches,
leaves and fruit.
The whole tree was a fruit.
Instead, the land grew trees
that have bark and stems and flowers.
The land created a world made of parts.
I often ask myself,
&quot;What would design be like
if objects were made of a single part?
Would we return to a better
state of creation?&quot;
So we looked for that biblical material,
that fruit-bearing fruit tree
kind of material, and we found it.
The second-most abundant biopolymer
on the planet is called chitin,
and some 100 million tons of it
are produced every year
by organisms such as shrimps,
crabs, scorpions and butterflies.
We thought if we could tune
its properties,
we could generate structures
that are multifunctional
out of a single part.
So that&#39;s what we did.
We called Legal Seafood --

(Laughter)

we ordered a bunch of shrimp shells,
we grinded them
and we produced chitosan paste.
By varying chemical concentrations,
we were able to achieve
a wide array of properties --
from dark, stiff and opaque,
to light, soft and transparent.
In order to print the structures
in large scale,
we built a robotically controlled
extrusion system with multiple nozzles.
The robot would vary
material properties on the fly
and create these 12-foot-long structures
made of a single material,
100 percent recyclable.
When the parts are ready,
they&#39;re left to dry
and find a form naturally
upon contact with air.
So why are we still
designing with plastics?
The air bubbles that were a byproduct
of the printing process
were used to contain
photosynthetic microorganisms
that first appeared on our planet
3.5 billion year ago,
as we learned yesterday.
Together with our collaborators
at Harvard and MIT,
we embedded bacteria
that were genetically engineered
to rapidly capture carbon
from the atmosphere
and convert it into sugar.
For the first time,
we were able to generate structures
that would seamlessly transition
from beam to mesh,
and if scaled even larger, to windows.
A fruit-bearing fruit tree.
Working with an ancient material,
one of the first lifeforms on the planet,
plenty of water and a little bit
of synthetic biology,
we were able to transform a structure
made of shrimp shells
into an architecture
that behaves like a tree.

And here&#39;s the best part:
for objects designed to biodegrade,
put them in the sea,
and they will nourish marine life;
place them in soil,
and they will help grow a tree.
The setting for our next exploration
using the same design principles
was the solar system.
We looked for the possibility
of creating life-sustaining clothing
for interplanetary voyages.
To do that, we needed to contain bacteria
and be able to control their flow.
So like the periodic table, we came up

with our own table of the elements:
new lifeforms that
were computationally grown,
additively manufactured
and biologically augmented.
I like to think of synthetic biology
as liquid alchemy,
only instead of transmuting
precious metals,
you&#39;re synthesizing new biological
functionality inside very small channels.
It&#39;s called microfluidics.
We 3D-printed our own channels
in order to control the flow
of these liquid bacterial cultures.
In our first piece of clothing,
we combined two microorganisms.
The first is cyanobacteria.
It lives in our oceans
and in freshwater ponds.
And the second, E. coli, the bacterium
that inhabits the human gut.
One converts light into sugar,
the other consumes that sugar
and produces biofuels
useful for the built environment.
Now, these two microorganisms
never interact in nature.
In fact, they never met each other.
They&#39;ve been here,
engineered for the first time,
to have a relationship
inside a piece of clothing.
Think of it as evolution
not by natural selection,
but evolution by design.
In order to contain these relationships,
we&#39;ve created a single channel
that resembles the digestive tract,
that will help flow these bacteria
and alter their function along the way.
We then started growing
these channels on the human body,
varying material properties
according to the desired functionality.
Where we wanted more photosynthesis,
we would design more transparent channels.
This wearable digestive system,
when it&#39;s stretched end to end,
spans 60 meters.
This is half the length
of a football field,
and 10 times as long
as our small intestines.
And here it is for the first time
unveiled at TED --
our first photosynthetic wearable,
liquid channels glowing with life
inside a wearable clothing.

(Applause)

Thank you.
Mary Shelley said, &quot;We are unfashioned
creatures, but only half made up.&quot;
What if design could provide
that other half?
What if we could create structures
that would augment living matter?
What if we could create
personal microbiomes
that would scan our skins,
repair damaged tissue
and sustain our bodies?
Think of this as a form of edited biology.
This entire collection, Wanderers,
that was named after planets,
was not to me really about fashion per se,
but it provided an opportunity
to speculate about the future
of our race on our planet and beyond,
to combine scientific insight
with lots of mystery
and to move away
from the age of the machine
to a new age of symbiosis
between our bodies,
the microorganisms that we inhabit,
our products and even our buildings.
I call this material ecology.
To do this, we always need
to return back to nature.
By now, you know that a 3D printer
prints material in layers.
You also know that nature doesn&#39;t.
It grows. It adds with sophistication.
This silkworm cocoon, for example,
creates a highly
sophisticated architecture,
a home inside which to metamorphisize.
No additive manufacturing today gets even
close to this level of sophistication.
It does so by combining not two materials,
but two proteins
in different concentrations.
One acts as the structure,
the other is the glue, or the matrix,
holding those fibers together.
And this happens across scales.
The silkworm first attaches itself
to the environment --
it creates a tensile structure --
and it then starts spinning
a compressive cocoon.
Tension and compression,
the two forces of life,
manifested in a single material.
In order to better understand
how this complex process works,
we glued a tiny earth magnet
to the head of a silkworm,
to the spinneret.
We placed it inside a box
with magnetic sensors,
and that allowed us to create
this 3-dimensional point cloud
and visualize the complex architecture
of the silkworm cocoon.
However, when we placed
the silkworm on a flat patch,
not inside a box,
we realized it would spin a flat cocoon
and it would still
healthily metamorphisize.
So we started designing different
environments, different scaffolds,
and we discovered that
the shape, the composition,
the structure of the cocoon, was directly
informed by the environment.
Silkworms are often boiled to death
inside their cocoons,
their silk unraveled and used
in the textile industry.
We realized that designing these templates
allowed us to give shape to raw silk
without boiling a single cocoon.

(Applause)

They would healthily metamorphisize,
and we would be able
to create these things.
So we scaled this process up
to architectural scale.
We had a robot spin
the template out of silk,
and we placed it on our site.
We knew silkworms migrated
toward darker and colder areas,
so we used a sun path diagram
to reveal the distribution
of light and heat on our structure.
We then created holes, or apertures,
that would lock in the rays
of light and heat,
distributing those silkworms
on the structure.
We were ready to receive the caterpillars.
We ordered 6,500 silkworms
from an online silk farm.
And after four weeks of feeding,
they were ready to spin with us.
We placed them carefully
at the bottom rim of the scaffold,
and as they spin they pupate,
they mate, they lay eggs,
and life begins all over again --
just like us but much, much shorter.
Bucky Fuller said that tension
is the great integrity,
and he was right.
As they spin biological silk
over robotically spun silk,
they give this entire
pavilion its integrity.
And over two to three weeks,
6,500 silkworms spin 6,500 kilometers.
In a curious symmetry, this is also
the length of the Silk Road.
The moths, after they hatch,
produce 1.5 million eggs.
This could be used for 250
additional pavilions for the future.
So here they are, the two worldviews.
One spins silk out of a robotic arm,
the other fills in the gaps.
If the final frontier of design
is to breathe life into the products
and the buildings around us,
to form a two-material ecology,
then designers must unite
these two worldviews.
Which brings us back, of course,
to the beginning.
Here&#39;s to a new age of design,
a new age of creation,
that takes us from
a nature-inspired design
to a design-inspired nature,
and that demands of us for the first time
that we mother nature.
Thank you.

(Applause)

Thank you very much. Thank you.

(Applause)

