
Across Europe and Central Asia,
approximately one million children live in large
residential institutions, usually known as orphanages.
Most people imagine orphanages as a benign environment
that care for children.
Others know more about the living conditions there,
but still think they&#39;re a necessary evil.
After all, where else would we put all of those children
who don&#39;t have any parents?
But 60 years of research has demonstrated
that separating children from their families
and placing them in large institutions
seriously harms their health and development,
and this is particularly true for young babies.
As we know, babies are born
without their full muscle development,
and that includes the brain.
During the first three years of life, the brain grows
to its full size, with most of that growth taking place
in the first six months. The brain develops
in response to experience and to stimulation.
Every time a young baby learns something new --
to focus its eyes,
to mimic a movement or a facial expression,
to pick something up, to form a word or to sit up --
new synaptic connections are being built in the brain.
New parents are astonished by the rapidity of this learning.
They are quite rightly amazed and delighted by their children&#39;s cleverness.
They communicate their delight to their children,
who respond with smiles,
and a desire to achieve more and to learn more.
This forming of the powerful attachment between child and parent
provides the building blocks for physical, social,
language, cognitive and psychomotor development.
It is the model for all future relationships with friends,
with partners and with their own children.
It happens so naturally in most families
that we don&#39;t even notice it. Most of us are unaware
of its importance to human development and, by extension,
to the development of a healthy society.
And it&#39;s only when it goes wrong that we start to realize
the importance of families to children.
In August, 1993, I had my first opportunity to witness
on a massive scale the impact on children
of institutionalization and the absence of parenting.
Those of us who remember the newspaper reports
that came out of Romania after the 1989 revolution
will recall the horrors of the conditions in some of those institutions.
I was asked to help the director of a large institution to
help prevent the separation of children from their families.
Housing 550 babies, this was Ceausescu&#39;s show orphanage,
and so I&#39;d been told the conditions were much better.
Having worked with lots of young children, I expected
the institution to be a riot of noise,
but it was as silent as a convent.
It was hard to believe there were any children there at all,
yet the director showed me into room after room,
each containing row upon row of cots,
in each of which lay a child staring into space.
In a room of 40 newborns, not one of them was crying.
Yet I could see soiled nappies, and I could see
that some of the children were distressed,
but the only noise was a low, continuous moan.
The head nurse told me proudly,
&quot;You see, our children are very well-behaved.&quot;
Over the next few days, I began to realize
that this quietness was not exceptional.
The newly admitted babies would cry for the first few hours,
but their demands were not met, and so eventually
they learned not to bother. Within a few days,
they were listless, lethargic, and staring into space
like all the others.
Over the years, many people and news reports
have blamed the personnel in the institutions
for the harm caused to the children, but often, one member
of staff is caring for 10, 20, and even 40 children.
Hence they have no option but to implement a regimented program.

The children must be woken at 7 and fed at 7:30.
At 8, their nappies must be changed, so a staff member
may have only 30 minutes to feed 10 or 20 children.

If a child soils its nappy at 8:30, he will have to wait
several hours before it can be changed again.
The child&#39;s daily contact with another human being
is reduced to a few hurried minutes of feeding and changing,
and otherwise their only stimulation is the ceiling,
the walls or the bars of their cots.
Since my first visit to Ceausescu&#39;s institution,
I&#39;ve seen hundreds of such places across 18 countries,
from the Czech Republic to Sudan.
Across all of these diverse lands and cultures,
the institutions, and the child&#39;s journey through them,
is depressingly similar.
Lack of stimulation often leads to self-stimulating behaviors
like hand-flapping, rocking back and forth,
or aggression, and in some institutions, psychiatric drugs
are used to control the behavior of these children,
whilst in others, children are tied up to prevent them
from harming themselves or others.
These children are quickly labeled as having disabilities
and transferred to another institution for children with disabilities.
Most of these children will never leave the institution again.
For those without disabilities, at age three,
they&#39;re transferred to another institution, and at age seven,
to yet another. Segregated according to age and gender,
they are arbitrarily separated from their siblings,
often without even a chance to say goodbye.
There&#39;s rarely enough to eat. They are often hungry.
The older children bully the little ones. They learn to
survive. They learn to defend themselves, or they go under.
When they leave the institution, they find it really difficult
to cope and to integrate into society.
In Moldova, young women raised in institutions
are 10 times more likely to be trafficked than their peers,
and a Russian study found that two years after leaving institutions,
young adults, 20 percent of them had a criminal record,
14 percent were involved in prostitution,
and 10 percent had taken their own lives.
But why are there so many orphans in Europe
when there hasn&#39;t been a great deal of war or disaster in recent years?
In fact, more than 95 percent of these children have living parents,
and societies tend to blame these parents
for abandoning these children, but research shows that
most parents want their children, and that the primary drivers
behind institutionalization
are poverty, disability and ethnicity.
Many countries have not developed inclusive schools,
and so even children with a very mild disability
are sent away to a residential special school,
at age six or seven.
The institution may be hundreds of miles away from the family home.
If the family&#39;s poor, they find it difficult to visit,
and gradually the relationship breaks down.
Behind each of the million children in institutions,
there is usually a story of parents who are desperate
and feel they&#39;ve run out of options, like Natalia in Moldova,
who only had enough money to feed her baby,
and so had to send her older son to the institution;
or Desi, in Bulgaria, who looked after her four children
at home until her husband died,
but then she had to go out to work full time,
and with no support, felt she had no option
but to place a child with disabilities in an institution;
or the countless young girls too terrified to tell their parents
they&#39;re pregnant, who leave their babies in a hospital;
or the new parents, the young couple who have
just found out that their firstborn child has a disability,
and instead of being provided with positive messages
about their child&#39;s potential, are told by the doctors,
&quot;Forget her, leave her in the institution,
go home and make a healthy one.&quot;
This state of affairs is neither necessary nor is it inevitable.
Every child has the right to a family, deserves
and needs a family, and children are amazingly resilient.
We find that if we get them out of institutions and into loving
families early on, they recover their developmental delays,
and go on to lead normal, happy lives.
It&#39;s also much cheaper to provide support to families
than it is to provide institutions.
One study suggests that a family support service
costs 10 percent of an institutional placement,
whilst good quality foster care
costs usually about 30 percent.
If we spend less on these children but on the right services,
we can take the savings and reinvest them in high quality
residential care for those few children with extremely complex needs.
Across Europe, a movement is growing to shift the focus
and transfer the resources from large institutions
that provide poor quality care to community-based services
that protect children from harm and allow them to develop
to their full potential. When I first started to work in Romania
nearly 20 years ago, there were 200,000 children living
in institutions, and more entering every day.
Now, there are less than 10,000, and
family support services are provided across the country.
In Moldova, despite extreme poverty and the terrible effects
of the global financial crisis, the numbers of children
in institutions has reduced by more than 50 percent
in the last five years, and the resources are being
redistributed to family support services and inclusive schools.
Many countries have developed national action plans for change.
The European Commission and other major donors
are finding ways to divert money from institutions
towards family support, empowering communities
to look after their own children.
But there is still much to be done to end the systematic
institutionalization of children.
Awareness-raising is required at every level of society.
People need to know the harm that institutions cause to children,
and the better alternatives that exist.
If we know people who are planning to support orphanages,
we should convince them to support family services instead.
Together, this is the one form of child abuse
that we could eradicate in our lifetime.
Thank you. 
(Applause)


(Applause)

