
Economists have been exploring

people&#39;s behavior for hundreds of years:
how we make decisions,
how we act individually and in groups,
how we exchange value.
They&#39;ve studied the institutions
that facilitate our trade,
like legal systems,
corporations,
marketplaces.
But there is a new,
technological institution
that will fundamentally change
how we exchange value,
and it&#39;s called the blockchain.
Now, that&#39;s a pretty bold statement,
but if you take nothing else
away from this talk,
I actually want you to remember
that while blockchain technology
is relatively new,
it&#39;s also a continuation
of a very human story,
and the story is this.
As humans, we find ways
to lower uncertainty about one another
so that we can exchange value.
Now, one of the first people
to really explore the idea
of institutions as a tool in economics
to lower our uncertainties
about one another
and be able to do trade
was the Nobel economist Douglass North.
He passed away at the end of 2015,
but North pioneered what&#39;s called
&quot;new institutional economics.&quot;
And what he meant by institutions
were really just formal rules
like a constitution,
and informal constraints, like bribery.
These institutions are really the grease
that allow our economic
wheels to function,
and we can see this play out
over the course of human history.
If we think back to when we were
hunter-gatherer economies,
we really just traded
within our village structure.
We had some informal constraints in place,
but we enforced
all of our trade with violence
or social repercussions.
As our societies grew more complex
and our trade routes grew more distant,
we built up more formal institutions,
institutions like banks for currency,
governments, corporations.
These institutions
helped us manage our trade
as the uncertainty
and the complexity grew,
and our personal control was much lower.
Eventually with the internet,
we put these same institutions online.
We built platform marketplaces
like Amazon, eBay, Alibaba,
just faster institutions
that act as middlemen
to facilitate human economic activity.
As Douglass North saw it,
institutions are a tool
to lower uncertainty
so that we can connect and exchange
all kinds of value in society.
And I believe we are now entering
a further and radical evolution
of how we interact and trade,
because for the first time,
we can lower uncertainty
not just with political
and economic institutions,
like our banks, our corporations,
our governments,
but we can do it with technology alone.
So what is the blockchain?
Blockchain technology
is a decentralized database
that stores a registry
of assets and transactions
across a peer-to-peer network.
It&#39;s basically a public registry
of who owns what and who transacts what.
The transactions are secured
through cryptography,
and over time, that transaction history
gets locked in blocks of data
that are then cryptographically
linked together and secured.
This creates an immutable,
unforgeable record
of all of the transactions
across this network.
This record is replicated
on every computer that uses the network.
It&#39;s not an app.
It&#39;s not a company.
I think it&#39;s closest in description
to something like Wikipedia.
We can see everything on Wikipedia.
It&#39;s a composite view that&#39;s constantly
changing and being updated.
We can also track those changes
over time on Wikipedia,
and we can create our own wikis,
because at their core,
they&#39;re just a data infrastructure.
On Wikipedia, it&#39;s an open platform
that stores words and images
and the changes to that data over time.
On the blockchain,
you can think of it
as an open infrastructure
that stores many kinds of assets.
It stores the history of custodianship,
ownership and location
for assets like
the digital currency Bitcoin,
other digital assets
like a title of ownership of IP.
It could be a certificate, a contract,
real world objects,
even personal identifiable information.
There are of course other
technical details to the blockchain,
but at its core, that&#39;s how it works.
It&#39;s this public registry
that stores transactions in a network
and is replicated so that it&#39;s very secure
and hard to tamper with.
Which brings me to my point
of how blockchains lower uncertainty
and how they therefore promise
to transform our economic systems
in radical ways.
So uncertainty is kind of a big term
in economics,
but I want to go through three forms of it
that we face in almost all
of our everyday transactions,
where blockchains can play a role.
We face uncertainties
like not knowing who we&#39;re dealing with,
not having visibility into a transaction
and not having recourse
if things go wrong.
So let&#39;s take the first example,
not knowing who we&#39;re dealing with.
Say I want to buy
a used smartphone on eBay.
The first thing I&#39;m going to do
is look up who I&#39;m buying from.
Are they a power user?
Do they have great reviews and ratings,
or do they have no profile at all?

Reviews, ratings, checkmarks:
these are the attestations
about our identities
that we cobble together today
and use to lower uncertainty
about who we&#39;re dealing with.
But the problem is
they&#39;re very fragmented.
Think about how many profiles you have.
Blockchains allow for us
to create an open, global platform
on which to store any attestation
about any individual
from any source.
This allows us to create a user-controlled
portable identity.
More than a profile,
it means you can selectively reveal
the different attributes about you
that help facilitate trade or interaction,
for instance that a government
issued you an ID,
or that you&#39;re over 21,
by revealing the cryptographic proof
that these details exist
and are signed off on.
Having this kind of portable identity
around the physical world
and the digital world
means we can do all kinds of human trade
in a totally new way.
So I&#39;ve talked about how blockchains
could lower uncertainty
in who we&#39;re dealing with.
The second uncertainty that we often face
is just not having transparency
into our interactions.
Say you&#39;re going to send me
that smartphone by mail.
I want some degree of transparency.
I want to know that the product I bought
is the same one that arrives in the mail
and that there&#39;s some record
for how it got to me.
This is true not just
for electronics like smartphones,
but for many kinds of goods and data,
things like medicine, luxury goods,
any kind of data or product
that we don&#39;t want tampered with.
The problem in many companies,
especially those that produce
something complicated like a smartphone,
is they&#39;re managing
all of these different vendors
across a horizontal supply chain.
All of these people
that go into making a product,
they don&#39;t have the same database.
They don&#39;t use the same infrastructure,
and so it becomes really hard to see
transparently a product evolve over time.
Using the blockchain, we can create
a shared reality
across nontrusting entities.
By this I mean
all of these nodes in the network
do not need to know each other
or trust each other,
because they each have the ability
to monitor and validate
the chain for themselves.
Think back to Wikipedia.
It&#39;s a shared database,
and even though it has multiple readers
and multiple writers at the same time,
it has one single truth.
So we can create that using blockchains.
We can create a decentralized database
that has the same efficiency of a monopoly
without actually creating
that central authority.
So all of these vendors,
all sorts of companies,
can interact using the same database
without trusting one another.
It means for consumers,
we can have a lot more transparency.
As a real-world object travels along,
we can see its digital certificate
or token move on the blockchain,
adding value as it goes.
This is a whole new world
in terms of our visibility.
So I&#39;ve talked about how blockchains
can lower our uncertainties about identity
and how they change
what we mean about transparency
in long distances and complex trades,
like in a supply chain.
The last uncertainty that we often face
is one of the most open-ended,
and it&#39;s reneging.
What if you don&#39;t send me the smartphone?
Can I get my money back?
Blockchains allow us to write code,
binding contracts,
between individuals
and then guarantee
that those contracts will bear out
without a third party enforcer.
So if we look at the smartphone example,
you could think about escrow.
You are financing that phone,
but you don&#39;t need to release the funds
until you can verify
that all the conditions have been met.
You got the phone.
I think this is one
of the most exciting ways
that blockchains lower our uncertainties,
because it means to some degree
we can collapse institutions
and their enforcement.
It means a lot of human economic activity
can get collateralized and automated,
and push a lot of human
intervention to the edges,
the places where information moves
from the real world to the blockchain.
I think what would probably
floor Douglass North
about this use of technology
is the fact that the very thing
that makes it work,
the very thing that keeps the blockchain
secure and verified,
is our mutual distrust.
So rather than all of our uncertainties
slowing us down
and requiring institutions
like banks, our governments,
our corporations,
we can actually harness
all of that collective uncertainty
and use it to collaborate and exchange
more and faster and more open.
Now, I don&#39;t want you
to get the impression
that the blockchain
is the solution to everything,
even though the media has said
that it&#39;s going to end world poverty,
it&#39;s also going to solve
the counterfeit drug problem
and potentially save the rainforest.
The truth is, this technology
is in its infancy,
and we&#39;re going to need to see
a lot of experiments take place
and probably fail
before we truly understand
all of the use cases
for our economy.
But there are tons of people
working on this,
from financial institutions
to technology companies,
start-ups and universities.
And one of the reasons is
that it&#39;s not just an economic evolution.
It&#39;s also an innovation
in computer science.
Blockchains give us
the technological capability
of creating a record of human exchange,
of exchange of currency,
of all kinds of digital
and physical assets,
even of our own personal attributes,
in a totally new way.
So in some ways,
they become a technological institution
that has a lot of the benefits
of the traditional institutions
we&#39;re used to using in society,
but it does this in a decentralized way.
It does this by converting
a lot of our uncertainties
into certainties.
So I think we need to start
preparing ourselves,
because we are about to face a world
where distributed, autonomous institutions
have quite a significant role.
Thank you.

(Applause)


Bruno Giussani: Thank you, Bettina.
I think I understood that it&#39;s coming,
it offers a lot of potential,
and it&#39;s complex.
What is your estimate
for the rate of adoption?

Bettina Warburg: I think
that&#39;s a really good question.
My lab is pretty much focused
on going the enterprise
and government route first,
because in reality,
blockchain is a complex technology.
How many of you actually understand
how the internet works?
But you use it every day,
so I think we&#39;re sort of facing
the same John Sculley idea
of technology should either be
invisible or beautiful,
and blockchain is kind of
neither of those things right now,
so it&#39;s better suited
for either really early adopters
who kind of get it and can tinker around
or for finding those best use cases
like identity or asset tracking
or smart contracts
that can be used at that level
of an enterprise or government.

BG: Thank you. Thanks for coming to TED.

BW: Thanks.

(Applause)

