
Twelve years ago, I picked up
a camera for the first time
to film the olive harvest
in a Palestinian village in the West Bank.
I thought I was there
to make a single documentary
and would then move on
to some other part of the world.
But something kept bringing me back.
Now, usually, when international audiences
hear about that part of the world,
they often just want
that conflict to go away.
The Israeli-Palestinian conflict is bad,
and we wish it could just disappear.
We feel much the same way
about other conflicts around the world.
But every time we turn
our attention to the news,
it seems like one more country
has gone up in flames.
So I&#39;ve been wondering
whether we should not start
looking at conflict in a different way --
whether instead of simply
wishing to end conflict,
we focus instead on how to wage conflict.
This has been a big question for me,
one I&#39;ve pursued together with my team
at the nonprofit Just Vision.
After witnessing several different kinds
of struggles in the Middle East,
I started noticing some patterns
on the more successful ones.
I wondered whether these variables
held across cases, and if they did,
what lessons we could glean
for waging constructive conflict,
in Palestine, Israel and elsewhere.
There is some science about this.
In a study of 323
major political conflicts
from 1900 to 2006,
Maria Stephan and Erica Chenoweth
found that nonviolent campaigns
were almost 100 percent more likely
to lead to success than violent campaigns.
Nonviolent campaigns are also
less likely to cause physical harm
to those waging the campaign,
as well as their opponents.
And, critically, they typically lead
to more peaceful and democratic societies.
In other words, nonviolent resistance
is a more effective and constructive way
of waging conflict.
But if that&#39;s such an easy choice,
why don&#39;t more groups use it?
Political scientist Victor Asal
and colleagues
have looked at several factors
that shape a political group&#39;s
choice of tactics.
And it turns out
that the greatest predictor
of a movement&#39;s decision
to adopt nonviolence or violence
is not whether that group
is more left-wing or right-wing,
not whether the group is more or less
influenced by religious beliefs,
not whether it&#39;s up against
a democracy or a dictatorship,
and not even the levels of repression
that that group is facing.
The greatest predictor of a movement&#39;s
decision to adopt nonviolence
is its ideology regarding
the role of women in public life.

(Applause)

When a movement includes in its discourse
language around gender equality,
it increases dramatically
the chances it will adopt nonviolence,
and thus, the likelihood it will succeed.
The research squared up
with my own documentation
of political organizing
in Israel and Palestine.
I&#39;ve noticed that movements which
welcome women into leadership positions,
such as the one I documented
in a village called Budrus,
were much more likely
to achieve their goals.
This village was under a real threat
of being wiped off the map
when Israel started building
the separation barrier.
The proposed route would require
the destruction of this community&#39;s
olive groves, their cemeteries
and would ultimately
enclose the village from all sides.
Through inspired local leadership,
they launched a nonviolent resistance
campaign to stop that from happening.
The odds were massively
stacked against them.

But they had a secret weapon:
a 15-year-old girl
who courageously jumped
in front of a bulldozer
which was about to uproot
an olive tree, stopping it.
In that moment, the community
of Budrus realized what was possible
if they welcomed and encouraged women
to participate in public life.
And so it was that the women of Budrus
went to the front lines day after day,
using their creativity and acumen
to overcome multiple obstacles they faced
in a 10-month unarmed struggle.
And as you can probably
tell at this point,
they win at the end.
The separation barrier
was changed completely
to the internationally
recognized green line,
and the women of Budrus
came to be known across the West Bank
for their indomitable energy.

(Applause)

Thank you.
I want to pause for a second,
which you helped me do,
because I do want to tackle
two very serious misunderstandings
that could happen at this point.
The first one is that I don&#39;t believe
women are inherently or essentially
more peaceful than men.
But I do believe that in today&#39;s world,
women experience power differently.
Having had to navigate
being in the less powerful position
in multiple aspects of their lives,
women are often more adept
at how to surreptitiously
pressure for change
against large, powerful actors.
The term &quot;manipulative,&quot; often charged
against women in a derogatory way,
reflects a reality in which women
have often had to find ways
other than direct confrontation
to achieve their goals.
And finding alternatives
to direct confrontation
is at the core of nonviolent resistance.
Now to the second
potential misunderstanding.
I&#39;ve been talking a lot about
my experiences in the Middle East,
and some of you might be thinking now
that the solution then is for us
to educate Muslim and Arab societies
to be more inclusive of their women.
If we were to do that,
they would be more successful.
They do not need this kind of help.
Women have been part
of the most influential movements
coming out of the Middle East,
but they tend to be invisible
to the international community.
Our cameras are largely focused on the men
who often end up involved
in the more confrontational scenes
that we find so irresistible
in our news cycle.
And we end up with a narrative
that not only erases women
from the struggles in the region
but often misrepresents
the struggles themselves.
In the late 1980s,
an uprising started in Gaza,
and quickly spread to the West Bank
and East Jerusalem.
It came to be known as the First Intifada,
and people who have
any visual memory of it

generally conjure up something like this:
Palestinian men
throwing rocks at Israeli tanks.
The news coverage at the time
made it seem like stones,
Molotov cocktails and burning tires
were the only activities
taking place in the Intifada.
This period, though, was also marked
by widespread nonviolent organizing
in the forms of strikes, sit-ins
and the creation of parallel institutions.
During the First Intifada,
whole sectors of the Palestinian
civilian population mobilized,
cutting across generations,
factions and class lines.
They did this through networks
of popular committees,
and their use of direct action
and communal self-help projects
challenged Israel&#39;s very ability
to continue ruling the West Bank and Gaza.
According to the Israeli Army itself,
97 percent of activities
during the First Intifada were unarmed.
And here&#39;s another thing that is not
part of our narrative about that time.
For 18 months in the Intifada,
women were the ones

calling the shots behind the scenes:
Palestinian women from all walks of life
in charge of mobilizing
hundreds of thousands of people
in a concerted effort to withdraw
consent from the occupation.
Naela Ayesh, who strived to build
a self-sufficient Palestinian economy
by encouraging women in Gaza
to grow vegetables in their backyards,
an activity deemed illegal
by the Israeli authorities at that time;
Rabeha Diab, who took over
decision-making authority
for the entire uprising
when the men who had been running it
were deported;
Fatima Al Jaafari, who swallowed leaflets
containing the uprising&#39;s directives
in order to spread them
across the territories
without getting caught;
and Zahira Kamal,
who ensured the longevity of the uprising
by leading an organization
that went from 25 women
to 3,000 in a single year.
Despite their extraordinary achievements,
none of these women have made it
into our narrative of the First Intifada.
We do this in other parts
of the globe, too.
In our history books, for instance,
and in our collective consciousness,
men are the public faces and spokespersons
for the 1960s struggle
for racial justice in the United States.
But women were also
a critical driving force,
mobilizing, organizing,
taking to the streets.
How many of us think of Septima Clark
when we think of the United States
Civil Rights era?
Remarkably few.
But she played a crucial role
in every phase of the struggle,
particularly by emphasizing
literacy and education.
She&#39;s been omitted, ignored,
like so many other women
who played critical roles
in the United States
Civil Rights Movement.
This is not about getting credit.
It&#39;s more profound than that.
The stories we tell matter deeply
to how we see ourselves,
and to how we believe movements are run
and how movements are won.
The stories we tell about a movement
like the First Intifada
or the United States Civil Rights era
matter deeply
and have a critical influence
in the choices Palestinians,
Americans
and people around the world will make
next time they encounter an injustice
and develop the courage to confront it.
If we do not lift up the women who played
critical roles in these struggles,
we fail to offer up role models
to future generations.
Without role models, it becomes harder
for women to take up their rightful space
in public life.
And as we saw earlier,
one of the most critical variables
in determining whether
a movement will be successful or not
is a movement&#39;s ideology
regarding the role of women
in public life.
This is a question of whether we&#39;re moving
towards more democratic
and peaceful societies.
In a world where so much
change is happening,
and where change is bound to continue
at an increasingly faster pace,
it is not a question
of whether we will face conflict,
but rather a question
of which stories will shape
how we choose to wage conflict.
Thank you.

(Applause)

