
Einstein said that
&quot;I never think about the future —
it comes soon enough.&quot;
And he was right, of course.
So today, I&#39;m here to ask you to think of
how the future is happening now.
Over the past 200 years, the world has experienced
two major waves of innovation.
First, the Industrial Revolution
brought us machines and factories, railways,
electricity, air travel,
and our lives have never been the same.
Then the Internet revolution
brought us computing power, data networks,
unprecedented access
to information and communication,
and our lives have never been the same.
Now we are experiencing

another metamorphic change:
the industrial Internet.
It brings together intelligent machines,
advanced analytics,
and the creativity of people at work.
It&#39;s the marriage of minds and machines.
And our lives will never be the same.
In my current role, I see up close
how technology is beginning to transform
industrial sectors that play a huge role

in our economy and in our lives:
energy, aviation, transportation, health care.
For an economist, this is highly unusual,
and it&#39;s extremely exciting,
because this is a transformation
as powerful as the Industrial Revolution and more,
and before the Industrial Revolution,
there was no economic growth to speak of.
So what is this industrial Internet?
Industrial machines are being equipped
with a growing number of electronic sensors
that allow them to see, hear, feel
a lot more than ever before,
generating prodigious amounts of data.
Increasingly sophisticated analytics
then sift through the data,
providing insights that allow us
to operate the machines in entirely new ways,
a lot more efficiently.
And not just individual machines,
but fleets of locomotives, airplanes,
entire systems like power grids, hospitals.
It is asset optimization and system optimization.
Of course, electronic sensors
have been around for some time,

but something has changed:
a sharp decline in the cost of sensors
and, thanks to advances in cloud computing,
a rapid decrease in the cost of storing
and processing data.
So we are moving to a world
where the machines we work with
are not just intelligent; they are brilliant.
They are self-aware, they are predictive,
reactive and social.
It&#39;s jet engines, locomotives, gas turbines,
medical devices, communicating seamlessly
with each other and with us.
It&#39;s a world where information itself
becomes intelligent and comes to us
automatically when we need it
without having to look for it.
We are beginning to deploy
throughout the industrial system
embedded virtualization,
multi-core processor technology,
advanced cloud-based communications,
a new software-defined machine infrastructure
which allows machine functionality
to become virtualized in software,
decoupling machine software from hardware,
and allowing us to remotely and automatically
monitor, manage and upgrade industrial assets.
Why does any of this matter at all?
Well first of all, it&#39;s already allowing us
to shift towards preventive,
condition-based maintenance,
which means fixing machines
just before they break,
without wasting time
servicing them on a fixed schedule.
And this, in turn, is pushing us towards
zero unplanned downtime,
which means there will be no more power outages,
no more flight delays.
So let me give you a few examples
of how these brilliant machines work,
and some of the examples may seem trivial,
some are clearly more profound,
but all of them are going to
have a very powerful impact.
Let&#39;s start with aviation.
Today, 10 percent of all flights
cancellations and delays
are due to unscheduled maintenance events.
Something goes wrong unexpectedly.
This results in eight billion dollars in costs
for the airline industry globally every year,

not to mention the impact on all of us:
stress, inconvenience,
missed meetings as we sit helplessly
in an airport terminal.
So how can the industrial Internet help here?
We&#39;ve developed a preventive maintenance system
which can be installed on any aircraft.
It&#39;s self-learning and able to predict issues
that a human operator would miss.
The aircraft, while in flight,
will communicate with technicians on the ground.
By the time it lands, they will already know
if anything needs to be serviced.
Just in the U.S., a system like this can prevent
over 60,000 delays and cancellations every year,
helping seven million passengers
get to their destinations on time.
Or take healthcare.
Today, nurses spend an average
of 21 minutes per shift
looking for medical equipment.
That seems trivial, but it&#39;s less time spent
caring for patients.
St. Luke&#39;s Medical Center in Houston, Texas,
which has deployed industrial Internet technology
to electronically monitor and connect
patients, staff and medical equipment,
has reduced bed turnaround times
by nearly one hour.
If you need surgery, one hour matters.
It means more patients can be treated,
more lives can be saved.
Another medical center, in Washington state,
is piloting an application that allows
medical images from city scanners and MRIs
to be analyzed in the cloud,
developing better analytics
at a lower cost.
Imagine a patient
who has suffered a severe trauma,

and needs the attention of several specialists:
a neurologist, a cardiologist,
an orthopedic surgeon.
If all of them can have instantaneous
and simultaneous access
to scans and images as they are taken,
they will be able to deliver better healthcare faster.
So all of this translates into better health outcomes,
but it can also deliver substantial economic benefits.
Just a one-percent reduction in existing inefficiencies
could yield savings of over 60 billion dollars
to the healthcare industry worldwide,
and that is just a drop in the sea
compared to what we need to do to make healthcare
affordable on a sustainable basis.
Similar advances are happening in energy,
including renewable energy.
Wind farms equipped with new
remote monitorings and diagnostics
that allow wind turbines to talk to each other
and adjust the pitch of their
blades in a coordinated way,
depending on how the wind is blowing,
can now produce electricity at a cost
of less than five cents per kilowatt/hour.
Ten years ago, that cost was 30 cents,
six times as much.
The list goes on, and it will grow fast,
because industrial data are
now growing exponentially.
By 2020, they will account for over 50 percent
of all digital information.
But this is not just about data, so let me switch gears
and tell you how this is impacting already
the jobs we do every day,
because this new wave of innovation
is bringing about new tools and applications
that will allow us to collaborate
in a smarter and faster way,
making our jobs not just more efficient
but more rewarding.
Imagine a field engineer arriving at the wind farm
with a handheld device telling her
which turbines need servicing.
She already has all the spare parts,
because the problems were diagnosed in advanced.
And if she faces an unexpected issue,
the same handheld device will allow her to
communicate with colleagues at the service center,
let them see what she sees,
transmit data that they can run through diagnostics,
and they can stream videos that will guide her,
step by step, through whatever complex procedure
is needed to get the machines back up and running.
And their interaction gets documented
and stored in a searchable database.
Let&#39;s stop and think about this for a minute,
because this is a very important point.
This new wave of innovation is fundamentally
changing the way we work.
And I know that many of you will be concerned 
about the impact that innovation might have on jobs.
Unemployment is already high,
and there is always a fear 
that innovation will destroy jobs.
And innovation is disruptive.
But let me stress two things here.
First, we&#39;ve already lived through
mechanization of agriculture,
automation of industry,
and employment has gone up,
because innovation is fundamentally about growth.
It makes products more affordable.
It creates new demand, new jobs.
Second, there is a concern that in the future,
there will only be room for engineers,
data scientists, and other highly-specialized workers.
And believe me, as an economist, I am also scared.

But think about it:
Just as a child can easily figure out
how to operate an iPad,
so a new generation of mobile and intuitive
industrial applications will make life easier
for workers of all skill levels.
The worker of the future will be more like Iron Man
than the Charlie Chaplin of &quot;Modern Times.&quot;

And to be sure, new high-skilled jobs will be created:
mechanical digital engineers who understand
both the machines and the data;
managers who understand their industry
and the analytics and can reorganize the business
to take full advantage of the technology.
But now let&#39;s take a step back.
Let&#39;s look at the big picture.
There are people who argue that today&#39;s innovation
is all about social media and silly games,
with nowhere near the transformational power
of the Industrial Revolution.
They say that all the growth-enhancing innovations
are behind us.
And every time I hear this, I can&#39;t help thinking that
even back in the Stone Age,
there must have been a group of cavemen
sitting around a fire one day
looking very grumpy,
and looking disapprovingly
at another group of cavemen
rolling a stone wheel up and down a hill,
and saying to each other,
&quot;Yeah, this wheel thing,
cool toy, sure, but compared to fire,
it will have no impact.
The big discoveries are all behind us.&quot;

(Laughter)

This technological revolution
is as inspiring and transformational
as anything we have ever seen.
Human creativity and innovation
have always propelled us forward.
They&#39;ve created jobs.
They&#39;ve raised living standards.
They&#39;ve made our lives
healthier and more rewarding.
And the new wave of innovation
which is beginning to sweep through industry
is no different.
In the U.S. alone, the industrial Internet
could raise average income by 25 to 40 percent
over the next 15 years,
boosting growth to rates we
haven&#39;t seen in a long time,
and adding between 10 and 15
trillion dollars to global GDP.
That is the size of the entire U.S. economy today.
But this is not a foregone conclusion.
We are just at the beginning of this transformation,
and there will be barriers to break,
obstacles to overcome.
We will need to invest in the new technologies.
We will need to adapt organizations
and managerial practices.
We will need a robust cybersecurity approach
that protects sensitive information
and intellectual property
and safeguards critical infrastructure
from cyberattacks.
And the education system will need to evolve
to ensure students are equipped with the right skills.
It&#39;s not going to be easy,
but it is going to be worth it.
The economic challenges facing us are hard,
but when I walk the factory floor,
and I see how humans and brilliant machines
are becoming interconnected,
and I see the difference this makes
in a hospital, in an airport,
in a power generation plant, I&#39;m not just optimistic,
I&#39;m enthusiastic.
This new technological revolution is upon us.
So think about the future —
it will be here soon enough.
Thank you.

(Applause)

