
Looking deeply inside nature,
through the magnifying glass of science,
designers extract principles,
processes and materials
that are forming the very basis
of design methodology.
From synthetic constructs
that resemble biological materials,
to computational methods
that emulate neural processes,
nature is driving design.
Design is also driving nature.
In realms of genetics, regenerative
medicine and synthetic biology,
designers are growing novel technologies,
not foreseen or anticipated by nature.
Bionics explores the interplay
between biology and design.
As you can see, my legs are bionic.
Today, I will tell human stories
of bionic integration;
how electromechanics attached
to the body, and implanted inside the body
are beginning to bridge the gap
between disability and ability,
between human limitation
and human potential.
Bionics has defined my physicality.
In 1982, both of my legs were amputated
due to tissue damage from frostbite,
incurred during
a mountain-climbing accident.
At that time, I didn&#39;t
view my body as broken.
I reasoned that a human being
can never be &quot;broken.&quot;
Technology is broken.
Technology is inadequate.
This simple but powerful idea
was a call to arms,
to advance technology
for the elimination of my own disability,
and ultimately, the disability of others.
I began by developing specialized limbs
that allowed me to return
to the vertical world
of rock and ice climbing.
I quickly realized that the artificial
part of my body is malleable;
able to take on any form, any function --
a blank slate for which to create,
perhaps, structures that could extend
beyond biological capability.
I made my height adjustable.
I could be as short as five feet
or as tall as I&#39;d like.

(Laughter)

So when I was feeling bad about myself,
insecure, I would jack my height up.

(Laughter)

But when I was feeling
confident and suave,
I would knock my height down a notch,
just to give the competition a chance.

(Laughter)


(Applause)

Narrow-edged feet allowed me
to climb steep rock fissures,
where the human foot cannot penetrate,
and spiked feet enabled me
to climb vertical ice walls,
without ever experiencing
muscle leg fatigue.
Through technological innovation,
I returned to my sport,
stronger and better.
Technology had eliminated my disability,
and allowed me a new climbing prowess.
As a young man, I imagined a future world
where technology so advanced
could rid the world of disability,
a world in which neural
implants would allow
the visually impaired to see.
A world in which the paralyzed
could walk, via body exoskeletons.
Sadly, because of
deficiencies in technology,
disability is rampant in the world.
This gentleman is missing three limbs.
As a testimony to current technology,
he is out of the wheelchair,
but we need to do a better job in bionics,
to allow, one day, full rehabilitation
for a person with this level of injury.
At the MIT Media Lab, we&#39;ve established
the Center for Extreme Bionics.
The mission of the center
is to put forth fundamental science
and technological capability
that will allow the biomechatronic
and regenerative repair of humans,
across a broad range
of brain and body disabilities.
Today, I&#39;m going to tell you
how my legs function, how they work,
as a case in point for this center.
Now, I made sure to shave
my legs last night,
because I knew I&#39;d be showing them off.

(Laughter)

Bionics entails the engineering
of extreme interfaces.
There&#39;s three extreme

interfaces in my bionic limbs:
mechanical, how my limbs
are attached to my biological body;
dynamic, how they move
like flesh and bone;
and electrical, how they communicate
with my nervous system.
I&#39;ll begin with mechanical interface.
In the area of design,
we still do not understand
how to attach devices
to the body mechanically.
It&#39;s extraordinary to me
that in this day and age,
one of the most mature,
oldest technologies
in the human timeline, the shoe,
still gives us blisters.
How can this be?
We have no idea how to attach
things to our bodies.
This is the beautifully
lyrical design work
of Professor Neri Oxman
at the MIT Media Lab,
showing spatially varying
exoskeletal impedances,
shown here by color variation
in this 3D-printed model.
Imagine a future where clothing
is stiff and soft where you need it,
when you need it, for optimal
support and flexibility,
without ever causing discomfort.
My bionic limbs are attached
to my biological body
via synthetic skins
with stiffness variations,
that mirror my underlying
tissue biomechanics.
To achieve that mirroring, we first
developed a mathematical model
of my biological limb.
To that end, we used
imaging tools such as MRI,
to look inside my body,
to figure out the geometries
and locations of various tissues.
We also took robotic tools --
here&#39;s a 14-actuator circle
that goes around the biological limb.
The actuators come in,
find the surface of the limb,
measure its unloaded shape,
and then they push on the tissues
to measure tissue compliances
at each anatomical point.
We combine these imaging and robotic data
to build a mathematical description
of my biological limb, shown on the left.
You see a bunch of points, or nodes?
At each node, there&#39;s a color
that represents tissue compliance.
We then do a mathematical transformation
to the design of the synthetic skin,
shown on the right.

And we&#39;ve discovered optimality is:
where the body is stiff,
the synthetic skin should be soft,
where the body is soft,
the synthetic skin is stiff,
and this mirroring occurs
across all tissue compliances.
With this framework,
we&#39;ve produced bionic limbs
that are the most comfortable
limbs I&#39;ve ever worn.
Clearly, in the future, our clothing,
our shoes, our braces, our prostheses,
will no longer be designed
and manufactured using artisan strategies,
but rather, data-driven
quantitative frameworks.
In that future, our shoes
will no longer give us blisters.
We&#39;re also embedding
sensing and smart materials
into the synthetic skins.
This is a material developed
by SRI International, California.
Under electrostatic effect,
it changes stiffness.
So under zero voltage,
the material is compliant,
it&#39;s floppy like paper.
Then the button&#39;s pushed,
a voltage is applied,
and it becomes stiff as a board.
(Tapping sounds)
We embed this material
into the synthetic skin
that attaches my bionic limb
to my biological body.
When I walk here, it&#39;s no voltage.
My interface is soft and compliant.
The button&#39;s pushed,
voltage is applied, and it stiffens,
offering me a greater maneuverability
over the bionic limb.
We&#39;re also building exoskeletons.
This exoskeleton becomes stiff and soft
in just the right areas
of the running cycle,
to protect the biological joints
from high impacts and degradation.
In the future, we&#39;ll all
be wearing exoskeletons
in common activities, such as running.
Next, dynamic interface.
How do my bionic limbs
move like flesh and bone?
At my MIT lab, we study how humans
with normal physiologies
stand, walk and run.
What are the muscles doing,
and how are they controlled
by the spinal cord?
This basic science
motivates what we build.
We&#39;re building bionic ankles,
knees and hips.
We&#39;re building body parts
from the ground up.
The bionic limbs that I&#39;m wearing
are called BiOMs.
They&#39;ve been fitted
to nearly 1,000 patients,
400 of which have been
wounded U.S. soldiers.
How does it work?
At heel strike, under computer control,
the system controls stiffness,
to attenuate the shock
of the limb hitting the ground.
Then at mid-stance, the bionic limb
outputs high torques and powers
to lift the person
into the walking stride,
comparable to how muscles
work in the calf region.
This bionic propulsion is very important
clinically to patients.
So on the left, you see
the bionic device worn by a lady,
on the right, a passive device
worn by the same lady,
that fails to emulate
normal muscle function,
enabling her to do something

everyone should be able to do:
go up and down their steps at home.
Bionics also allows
for extraordinary athletic feats.
Here&#39;s a gentleman running
up a rocky pathway.
This is Steve Martin --
not the comedian --
who lost his legs in a bomb blast
in Afghanistan.
We&#39;re also building exoskeletal
structures using these same principles,
that wrap around the biological limb.
This gentleman does not have
any leg condition, any disability.
He has a normal physiology,
so these exoskeletons are applying
muscle-like torques and powers,
so that his own muscles need not
apply those torques and powers.
This is the first exoskeleton in history
that actually augments human walking.
It significantly reduces metabolic cost.
It&#39;s so profound in its augmentation,
that when a normal, healthy person
wears the device for 40 minutes
and then takes it off,
their own biological legs feel
ridiculously heavy and awkward.
We&#39;re beginning the age in which
machines attached to our bodies
will make us stronger
and faster and more efficient.

Moving on to electrical interface:
How do my bionic limbs communicate
with my nervous system?
Across my residual limb are electrodes
that measure the electrical
pulse of my muscles.
That&#39;s communicated to the bionic limb,
so when I think about moving
my phantom limb,
the robot tracks those movement desires.
This diagram shows fundamentally
how the bionic limb is controlled.
So we model the missing biological limb,
and we&#39;ve discovered
what reflexes occurred,
how the reflexes of the spinal cord
are controlling the muscles.
And that capability is embedded
in the chips of the bionic limb.
What we&#39;ve done, then, is we modulate
the sensitivity of the reflex,
the modeled spinal reflex,
with the neural signal,
so when I relax my muscles
in my residual limb,
I get very little torque and power,
but the more I fire my muscles,
the more torque I get,
and I can even run.
And that was the first demonstration
of a running gait under neural command.
Feels great.

(Applause)

We want to go a step further.
We want to actually close the loop
between the human
and the bionic external limb.
We&#39;re doing experiments
where we&#39;re growing nerves,
transected nerves,
through channels, or micro-channel arrays.
On the other side of the channel,
the nerve then attaches to cells,
skin cells and muscle cells.
In the motor channels, we can sense
how the person wishes to move.
That can be sent out wirelessly
to the bionic limb,
then [sensory information]
on the bionic limb
can be converted to stimulations
in adjacent channels,
sensory channels.
So when this is fully developed
and for human use,
persons like myself will not only have
synthetic limbs that move
like flesh and bone,
but actually feel like flesh and bone.
This video shows Lisa Mallette,
shortly after being fitted
with two bionic limbs.
Indeed, bionics is making
a profound difference in people&#39;s lives.

(Video) Lisa Mallette: Oh my God.

LM: Oh my God, I can&#39;t believe it!
(Video) 
(Laughter)


LM: It&#39;s just like I&#39;ve got a real leg!

Woman: Now, don&#39;t start running.

Man: Now turn around,
and do the same thing walking up,
but get on your heel to toe, like you
would normally just walk on level ground.
Try to walk right up the hill.

LM: Oh my God.

Man: Is it pushing you up?

LM: Yes! I&#39;m not even --
I can&#39;t even describe it.

Man: It&#39;s pushing you right up.

Hugh Herr: Next week,
I&#39;m visiting the Center --
Thank you. Thank you.

(Applause)

Thank you.
Next week I&#39;m visiting the Center
for Medicare and Medicaid Services,
and I&#39;m going to try to convince CMS
to grant appropriate
code language and pricing,
so this technology can be made available
to the patients that need it.

(Applause)

Thank you.

(Applause)

It&#39;s not well appreciated,
but over half of the world&#39;s population
suffers from some form of cognitive,
emotional, sensory or motor condition,
and because of poor technology,
too often, conditions result in disability
and a poorer quality of life.
Basic levels of physiological function
should be a part of our human rights.
Every person should have the right
to live life without disability
if they so choose --
the right to live life
without severe depression;
the right to see a loved one,
in the case of seeing-impaired;
or the right to walk or to dance,
in the case of limb paralysis
or limb amputation.
As a society, we can
achieve these human rights,
if we accept the proposition
that humans are not disabled.
A person can never be broken.
Our built environment, our technologies,
are broken and disabled.
We the people need not
accept our limitations,
but can transcend disability
through technological innovation.
Indeed, through fundamental advances
in bionics in this century,
we will set the technological foundation
for an enhanced human experience,
and we will end disability.
I&#39;d like to finish up
with one more story, a beautiful story.
The story of Adrianne Haslet-Davis.
Adrianne lost her left leg
in the Boston terrorist attack.
I met Adrianne when this photo was taken,
at Spaulding Rehabilitation Hospital.
Adrianne is a dancer, a ballroom dancer.
Adrianne breathes and lives dance.
It is her expression. It is her art form.
Naturally, when she lost her limb
in the Boston terrorist attack,
she wanted to return to the dance floor.
After meeting her
and driving home in my car,
I thought, I&#39;m an MIT professor.
I have resources.
Let&#39;s build her a bionic limb,
to enable her to go back
to her life of dance.
I brought in MIT scientists
with expertise in prosthetics,
robotics, machine learning
and biomechanics,
and over a 200-day research period,
we studied dance.
We brought in dancers
with biological limbs,
and we studied how they move,
what forces they apply on the dance floor,
and we took those data,
and we put forth
fundamental principles of dance,
reflexive dance capability,
and we embedded that intelligence
into the bionic limb.
Bionics is not only about making
people stronger and faster.
Our expression, our humanity
can be embedded into electromechanics.
It was 3.5 seconds between the bomb blasts
in the Boston terrorist attack.
In 3.5 seconds, the criminals and cowards
took Adrianne off the dance floor.
In 200 days, we put her back.
We will not be intimidated, brought down,
diminished, conquered or stopped
by acts of violence.

(Applause)

Ladies and gentlemen, please allow me
to introduce Adrianne Haslet-Davis,
her first performance since the attack.
She&#39;s dancing with Christian Lightner.

(Applause)


(Music: &quot;Ring My Bell&quot;
performed by Enrique Iglesias)

(Applause)

Ladies and gentlemen,

members of the research team:
Elliott Rouse
and Nathan Villagaray-Carski.
Elliott and Nathan.

(Applause)

