
&quot;You have cancer.&quot;
Sadly, about 40 percent of us will hear
those three words within our lifetime,
and half will not survive.
This means that two out of five
of your closest friends and relatives
will be diagnosed
with some form of cancer,
and one will die.
Beyond the physical hardships,
roughly one-third
of cancer survivors here in the US
will go into debt from treatment.
And they&#39;re at least two and a half times
more likely to declare bankruptcy
than those without cancer.
This disease is pervasive.
It&#39;s emotionally draining
and, for many,
financially destructive.
But a cancer diagnosis
doesn&#39;t have to be a death sentence.
Finding cancer early,
closer its genesis,
is one of the critical factors
to improving treatment options,
reducing its emotional impact
and minimizing financial burdens.
Most importantly,
finding cancer early --
which is one of the primary
aims of my research --
greatly enhances your odds of survival.
If we just look at the case
of breast cancer for example,
we find that those who are diagnosed
and treated at stage one
have a five-year survival rate
of nearly 100 percent --
odds that decrease to just 22 percent
if treated at stage four.
And similar trends are found
for colorectal and ovarian cancer.
Now, we&#39;re all aware
that an early diagnosis that is accurate
is critical for survival.
The problem is that many
cancer diagnostic tools are invasive,
costly,
often inaccurate
and they can take an agonizing
amount of time to get the results back.
Still worse, when it comes
to some forms of cancer,
such as ovarian,
liver or pancreatic cancer,
good screening methods simply don&#39;t exist,
meaning that often people wait
until physical symptoms surface,
which are themselves already
indicators of late-stage progression.
Like a tornado strike in an area
without an early warning system,
there is no alarm to warn,
for the danger is already at your doorstep
when your odds of survival
are greatly reduced.
Having the convenience and accessibility
of regular screening options
that are affordable, noninvasive
and could provide results much sooner,
would provide us with a formidable
weapon in the fight against cancer.
An early warning would allow us
to get out ahead of the disease
instead of merely
following in its relentless wake.
And this is exactly what I&#39;ve been doing.
For the past three years,
I&#39;ve been developing technologies
that could ultimately aid clinicians
with rapid, early-stage
cancer diagnostics.
And I&#39;ve been fueled
by a deep scientific curiosity,
and a passion to change these statistics.
Last year however,
this fight became much more personal
when my wife was diagnosed
with breast cancer.
It was an experience that added a strong
and unexpected emotional dimension
to these efforts.
I know firsthand how life-altering
treatment can be,
and I&#39;m keenly aware
of the emotional havoc
that cancer can wreak on a family,
which in our case
included our two young daughters.
Because we found it early
during a routine mammogram,
we were able to focus
primarily on treatment options
for the localized tumor,
reaffirming to me
how important an early diagnosis is.
Unlike other forms of cancer,
mammograms do offer an early-stage
screening option for breast cancer.
Still, not everyone has this done,
or they may develop breast cancer
before the middle age recommendation
for having a mammogram.
So, there&#39;s still
a lot of room for improvement,
even for cancers
that do have screening options,
and, of course, considerable benefits
for those that don&#39;t.
A key challenge then
for cancer researchers
is to develop methods
that make regular screening
for many types of cancers
much more accessible.
Imagine a scenario
where during your regular checkup,
your doctor can take
a simple, noninvasive urine sample,
or other liquid biopsy,
and present you with the results
before you even leave the doctor&#39;s office.
Such a technology could
dramatically reduce the number of people
who slip through the net
of an early-stage cancer diagnosis.
My research team
of engineers and biochemists
is working on exactly this challenge.
We&#39;re working on ways to frequently
activate an early-stage cancer alarm
by enabling regular screenings
that would start when a person is healthy
so that action could be taken
to stop cancer the moment it emerges,
and before it can progress
beyond its infancy.
The silver bullet in this case
are tiny vesicles,
little escape pods regularly shed
by cells called exosomes.
Exosomes are important biomarkers
that provide an early-warning system
for the development of cancer.
And because they&#39;re abundantly present
in just about every bodily fluid,
including blood, urine and saliva,
they&#39;re extremely attractive
for noninvasive liquid biopsies.
There&#39;s just one problem.
An automated system for rapidly sorting
these important biomarkers
is not currently available.
We&#39;ve created a technology
that we call nano-DLD

that is capable of precisely this:
automated exosome isolation
to aid rapid cancer diagnostics.
Exosomes are the newest
early-warning weapon, if you will,
to emerge on the liquid biopsy front.
And they&#39;re really, really small.
They measure just 30 to 150
nanometers in diameter.
This is so tiny
that you could fit about a million
of them into a single red blood cell.
That&#39;s roughly the difference
between a golf ball
and a fine grain piece of sand.
Once thought to be little bins
for unwanted cellular waste,
it has been found
that cells actually communicate
by producing and absorbing these exosomes
which contain surface receptors,
proteins and other genetic material
collected from their cell of origin.
When absorbed by a neighboring cell,
exosomes release their contents
into the receiving cell,
and can set in motion
fundamental changes in gene expression --
some good,
and this is where cancer comes in,
some bad.
Because they are clothed
in the material of the mother cell,
and contain a sample of its environment,
they provide a genetic snapshot
of that cell&#39;s health and its origin.
All of these qualities
make exosomes invaluable messengers
that potentially allow physicians
to eavesdrop on your health
at the cellular level.
To catch cancer early, however,
you have to frequently
intercept these messages
to determine when cancer-causing
troublemakers within your body
decide to start staging a coup,
which is why regular
screening is so critical
and why we&#39;re developing
technologies to make this possible.
While the first exosome-based diagnostics
emerged on the market just this year,
they are not yet part
of mainstream healthcare options.
In addition to their recent emergence,
another factor that&#39;s limiting
their widespread adoption
is that currently, no automated
exosome isolation system exists
to make regular screening
economically accessible.
The current gold standard
for exosome isolation
includes ultracentrifugation,
a process requiring
expensive laboratory equipment,
a trained lab tech
and about 30 hours of time
to process a sample.
We&#39;ve come up with a different approach
for achieving automated exosome isolation
from a sample such as urine.
We use a chip-based, continuous flow
separation technique
called deterministic lateral displacement.
And we have done with it
what the semiconductor industry has done
so successfully for the past 50 years.
We shrunk the dimensions
of this technology
from the micron scale
to the true nanoscale.
So how does it work?
In a nutshell,
a set of tiny pillars
separated by nanoscopic gaps
are arranged in such a way
that the system divides
the fluid into streamlines,
with the larger cancer-related
nanoparticles being separated
through a process of redirection
from the smaller, healthier ones,
which can in contrast
move around the pillars
in a zigzag-type motion
in the direction of fluid flow.
The net result is a complete separation
of these two particle populations.
You can visualize this separation process
similar to traffic on a highway
that separates into two roads,
with one road going into
a low-clearance tunnel under a mountain,
and the other road going around it.
Here, smaller cars
can go through the tunnel
while larger trucks,
carrying potentially hazardous material,
are forced to take the detour route.
Traffic is effectively separated
by size and contents
without impeding its flow.
And this is exactly how our system works
on a much, much smaller scale.
The idea here is that
the separation process for screening
could be as simple as processing
a sample of urine, blood or saliva,
which is a near-term possibility
within the next few years.
Ultimately, it could be used
to isolate and detect target exosomes
associated with
a particular type of cancer,
sensing and reporting
their presence within minutes.
This would make rapid diagnostics
virtually painless.
Broadly speaking,
the ability to separate
and enrich biomarkers
with nanoscale precision
in an automated way,
opens the door to better understanding
diseases such as cancer,
with applications ranging
from sample preparation to diagnostics,
and from drug resistance
monitoring to therapeutics.
Even before my wife&#39;s bout with cancer,
it was a dream of mine to facilitate
the automation of this process --
to make regular screening more accessible,
similar to the way Henry Ford
made the automobile accessible
to the general population
through development of the assembly line.
Automation is the key to accessibility.
And in the spirit of the Hoover dream,
&quot;a chicken in every pot
and a car in every garage,&quot;
we&#39;re developing a technology
that could ultimately place
an early-warning cancer detection system
in every home.
This would allow
every man, woman and child
the opportunity to be regularly tested
while they&#39;re still healthy,
catching cancer when it first emerges.
It is my hope and dream
to help people around the world
avoid the high costs --
physical, financial and emotional --
faced by today&#39;s cancer patients,
hardships that I&#39;m well acquainted with.
I&#39;m also happy to report that because
we caught my wife&#39;s cancer early,
her treatment was successful,
and she is now, thankfully, cancer-free.

(Applause)

It is an outcome that I would like to see
for everyone with a cancer diagnosis.
With the work that my team
has already done
on separation of nanoscale biomarkers
for rapid, early-stage cancer diagnostics,
I am optimistic
that within the next decade,
this type of technology will be available,
helping protect our friends,
our family and future generations.
Even if we are so unlucky
as to be diagnosed with cancer,
that early-stage alarm
will provide a strong beacon of hope.
Thank you.

(Applause)

