
Science,
science has allowed us to know so much
about the far reaches of the universe,
which is at the same time tremendously important
and extremely remote,
and yet much, much closer,
much more directly related to us,
there are many things we don&#39;t really understand.
And one of them is the extraordinary
social complexity of the animals around us,
and today I want to tell you a few stories
of animal complexity.
But first, what do we call complexity?
What is complex?
Well, complex is not complicated.
Something complicated comprises many small parts,
all different, and each of them
has its own precise role in the machinery.
On the opposite, a complex system
is made of many, many similar parts,
and it is their interaction
that produces a globally coherent behavior.
Complex systems have many interacting parts
which behave according to simple, individual rules,
and this results in emergent properties.
The behavior of the system as a whole
cannot be predicted
from the individual rules only.
As Aristotle wrote,
the whole is greater than the sum of its parts.
But from Aristotle, let&#39;s move onto
a more concrete example of complex systems.
These are Scottish terriers.
In the beginning, the system is disorganized.

Then comes a perturbation: milk.
Every individual starts pushing in one direction
and this is what happens.
The pinwheel is an emergent property
of the interactions between puppies
whose only rule is to try to keep access to the milk
and therefore to push in a random direction.
So it&#39;s all about finding the simple rules
from which complexity emerges.
I call this simplifying complexity,
and it&#39;s what we do at the chair of systems design
at ETH Zurich.
We collect data on animal populations,
analyze complex patterns, try to explain them.
It requires physicists who work with biologists,
with mathematicians and computer scientists,
and it is their interaction that produces
cross-boundary competence
to solve these problems.
So again, the whole is greater
than the sum of the parts.
In a way, collaboration
is another example of a complex system.
And you may be asking yourself
which side I&#39;m on, biology or physics?
In fact, it&#39;s a little different,
and to explain, I need to tell you
a short story about myself.
When I was a child,
I loved to build stuff, to
create complicated machines.
So I set out to study electrical engineering
and robotics,
and my end-of-studies project
was about building a robot called ER-1 --
it looked like this—
that would collect information from its environment
and proceed to follow a white line on the ground.
It was very, very complicated,
but it worked beautifully in our test room,
and on demo day, professors had 
assembled to grade the project.
So we took ER-1 to the evaluation room.
It turned out, the light in that room
was slightly different.
The robot&#39;s vision system got confused.
At the first bend in the line,
it left its course, and crashed into a wall.
We had spent weeks building it,
and all it took to destroy it
was a subtle change in the color of the light
in the room.
That&#39;s when I realized that
the more complicated you make a machine,
the more likely that it will fail
due to something absolutely unexpected.
And I decided that, in fact,
I didn&#39;t really want to create complicated stuff.
I wanted to understand complexity,
the complexity of the world around us
and especially in the animal kingdom.
Which brings us to bats.
Bechstein&#39;s bats are a common
species of European bats.
They are very social animals.
Mostly they roost, or sleep, together.
And they live in maternity colonies,
which means that every spring,
the females meet after the winter hibernation,
and they stay together for about six months
to rear their young,
and they all carry a very small chip,
which means that every time one of them
enters one of these specially equipped bat boxes,
we know where she is,
and more importantly,
we know with whom she is.
So I study roosting associations in bats,
and this is what it looks like.
During the day, the bats roost
in a number of sub-groups in different boxes.
It could be that on one day,
the colony is split between two boxes,
but on another day,
it could be together in a single box,
or split between three or more boxes,
and that all seems rather erratic, really.
It&#39;s called fission-fusion dynamics,
the property for an animal group
of regularly splitting and merging
into different subgroups.
So what we do is take all these data
from all these different days
and pool them together
to extract a long-term association pattern
by applying techniques with network analysis
to get a complete picture
of the social structure of the colony.
Okay? So that&#39;s what this picture looks like.
In this network, all the circles
are nodes, individual bats,
and the lines between them
are social bonds, associations between individuals.
It turns out this is a very interesting picture.
This bat colony is organized
in two different communities
which cannot be predicted
from the daily fission-fusion dynamics.
We call them cryptic social units.

Even more interesting, in fact:
Every year, around October,
the colony splits up,
and all bats hibernate separately,
but year after year,
when the bats come together again in the spring,
the communities stay the same.
So these bats remember their friends
for a really long time.
With a brain the size of a peanut,
they maintain individualized,
long-term social bonds,
We didn&#39;t know that was possible.
We knew that primates
and elephants and dolphins could do that,
but compared to bats, they have huge brains.
So how could it be
that the bats maintain this complex,
stable social structure
with such limited cognitive abilities?
And this is where complexity brings an answer.
To understand this system,
we built a computer model of roosting,
based on simple, individual rules,
and simulated thousands and thousands of days
in the virtual bat colony.
It&#39;s a mathematical model,
but it&#39;s not complicated.
What the model told us is that, in a nutshell,
each bat knows a few other colony members
as her friends, and is just slightly more likely
to roost in a box with them.
Simple, individual rules.
This is all it takes to explain
the social complexity of these bats.
But it gets better.
Between 2010 and 2011,
the colony lost more than two thirds of its members,
probably due to the very cold winter.
The next spring, it didn&#39;t form two communities
like every year,
which may have led the whole colony to die
because it had become too small.
Instead, it formed a single, cohesive social unit,
which allowed the colony to survive that season
and thrive again in the next two years.
What we know is that the bats
are not aware that their colony is doing this.
All they do is follow simple association rules,
and from this simplicity
emerges social complexity
which allows the colony to be resilient
against dramatic changes
in the population structure.
And I find this incredible.
Now I want to tell you another story,
but for this we have to travel from Europe
to the Kalahari Desert in South Africa.
This is where meerkats live.
I&#39;m sure you know meerkats.
They&#39;re fascinating creatures.
They live in groups with a
very strict social hierarchy.
There is one dominant pair,
and many subordinates,
some acting as sentinels,
some acting as babysitters,
some teaching pups, and so on.
What we do is put very small GPS collars
on these animals
to study how they move together,
and what this has to do with their social structure.
And there&#39;s a very interesting example
of collective movement in meerkats.
In the middle of the reserve which they live in
lies a road.
On this road there are cars, so it&#39;s dangerous.
But the meerkats have to cross it
to get from one feeding place to another.
So we asked, how exactly do they do this?
We found that the dominant female
is mostly the one who leads the group to the road,
but when it comes to crossing it, crossing the road,
she gives way to the subordinates,
a manner of saying,
&quot;Go ahead, tell me if it&#39;s safe.&quot;
What I didn&#39;t know, in fact,
was what rules in their behavior the meerkats follow
for this change at the edge of the group to happen
and if simple rules were sufficient to explain it.
So I built a model, a model of simulated meerkats
crossing a simulated road.
It&#39;s a simplistic model.
Moving meerkats are like random particles
whose unique rule is one of alignment.
They simply move together.
When these particles get to the road,
they sense some kind of obstacle,
and they bounce against it.
The only difference
between the dominant female, here in red,
and the other individuals,
is that for her, the height of the obstacle,
which is in fact the risk perceived from the road,
is just slightly higher,
and this tiny difference
in the individual&#39;s rule of movement
is sufficient to explain what we observe,
that the dominant female
leads her group to the road
and then gives way to the others
for them to cross first.
George Box, who was an English statistician,
once wrote, &quot;All models are false,
but some models are useful.&quot;
And in fact, this model is obviously false,
because in reality, meerkats are
anything but random particles.
But it&#39;s also useful,
because it tells us that extreme simplicity
in movement rules at the individual level
can result in a great deal of complexity
at the level of the group.
So again, that&#39;s simplifying complexity.
I would like to conclude
on what this means for the whole species.
When the dominant female
gives way to a subordinate,
it&#39;s not out of courtesy.
In fact, the dominant female
is extremely important for the cohesion of the group.
If she dies on the road, the whole group is at risk.
So this behavior of risk avoidance
is a very old evolutionary response.
These meerkats are replicating an evolved tactic
that is thousands of generations old,
and they&#39;re adapting it to a modern risk,
in this case a road built by humans.
They adapt very simple rules,
and the resulting complex behavior
allows them to resist human encroachment
into their natural habitat.
In the end,
it may be bats which change their social structure
in response to a population crash,
or it may be meerkats
who show a novel adaptation to a human road,
or it may be another species.
My message here -- and it&#39;s not a complicated one,
but a simple one of wonder and hope --
my message here is that animals
show extraordinary social complexity,
and this allows them to adapt
and respond to changes in their environment.
In three words, in the animal kingdom,
simplicity leads to complexity
which leads to resilience.
Thank you.

(Applause)


Dania Gerhardt: Thank you very much, Nicolas,
for this great start. Little bit nervous?

Nicolas Perony: I&#39;m okay, thanks.

DG: Okay, great. I&#39;m sure a 
lot of people in the audience
somehow tried to make associations
between the animals you were talking about --
the bats, meerkats -- and humans.

You brought some examples:
The females are the social ones,
the females are the dominant ones,
I&#39;m not sure who thinks how.
But is it okay to do these associations?
Are there stereotypes you can confirm in this regard
that can be valid across all species?

NP: Well, I would say there are also
counter-examples to these stereotypes.
For examples, in sea horses or in koalas, in fact,
it is the males who take care of the young always.
And the lesson is that it&#39;s often difficult,
and sometimes even a bit dangerous,
to draw parallels between humans and animals.
So that&#39;s it.

DG: Okay. Thank you very much for this great start.
Thank you, Nicolas Perony.
