
I&#39;m going to talk a little bit about strategy
and its relationship with technology.
We tend to think of business strategy
as being a rather abstract body
of essentially economic thought,
perhaps rather timeless.
I&#39;m going to argue that, in fact,
business strategy has always been premised
on assumptions about technology,
that those assumptions are changing,
and, in fact, changing quite dramatically,
and that therefore what that will drive us to
is a different concept of what we mean
by business strategy.
Let me start, if I may,
with a little bit of history.
The idea of strategy in business

owes its origins to two intellectual giants:
Bruce Henderson, the founder of BCG,
and Michael Porter, professor
at the Harvard Business School.
Henderson&#39;s central idea was what you might call
the Napoleonic idea of concentrating mass
against weakness, of overwhelming the enemy.
What Henderson recognized was that,
in the business world,
there are many phenomena which are characterized
by what economists would call increasing returns --
scale, experience.
The more you do of something,
disproportionately the better you get.
And therefore he found a logic for investing
in such kinds of overwhelming mass
in order to achieve competitive advantage.
And that was the first introduction
of essentially a military concept of strategy
into the business world.
Porter agreed with that premise,
but he qualified it.
He pointed out, correctly, that that&#39;s all very well,
but businesses actually have multiple steps to them.
They have different components,
and each of those components might be driven
by a different kind of strategy.
A company or a business
might actually be advantaged
in some activities but disadvantaged in others.
He formed the concept of the value chain,
essentially the sequence of steps with which
a, shall we say, raw material, becomes a component,
becomes assembled into a finished product,
and then is distributed, for example,
and he argued that advantage accrued
to each of those components,
and that the advantage of the whole
was in some sense the sum or the average
of that of its parts.
And this idea of the value chain was predicated
on the recognition that
what holds a business together is transaction costs,
that in essence you need to coordinate,
organizations are more efficient at coordination
than markets, very often,
and therefore the nature and role and boundaries
of the cooperation are defined by transaction costs.
It was on those two ideas,
Henderson&#39;s idea of increasing returns
to scale and experience,
and Porter&#39;s idea of the value chain,
encompassing heterogenous elements,
that the whole edifice of business strategy
was subsequently erected.
Now what I&#39;m going to argue is
that those premises are, in fact, being invalidated.
First of all, let&#39;s think about transaction costs.
There are really two components
to transaction costs.
One is about processing information,
and the other is about communication.
These are the economics of
processing and communicating
as they have evolved over a long period of time.
As we all know from so many contexts,
they have been radically transformed
since the days when Porter and Henderson
first formulated their theories.
In particular, since the mid-&#39;90s,
communications costs have actually been falling
even faster than transaction costs,
which is why communication, the Internet,
has exploded in such a dramatic fashion.
Now, those falling transaction costs
have profound consequences,
because if transaction costs are the glue
that hold value chains together, and they are falling,
there is less to economize on.
There is less need for vertically
integrated organization,
and value chains at least can break up.
They needn&#39;t necessarily, but they can.
In particular, it then becomes possible for
a competitor in one business
to use their position in one step of the value chain
in order to penetrate or attack
or disintermediate the competitor in another.
That is not just an abstract proposition.
There are many very specific stories
of how that actually happened.
A poster child example was
the encyclopedia business.
The encyclopedia business
in the days of leatherbound books
was basically a distribution business.
Most of the cost was the
commission to the salesmen.
The CD-ROM and then the Internet came along,
new technologies made the distribution of knowledge
many orders of magnitude cheaper,
and the encyclopedia industry collapsed.
It&#39;s now, of course, a very familiar story.
This, in fact, more generally was the story
of the first generation of the Internet economy.
It was about falling transaction costs
breaking up value chains
and therefore allowing disintermediation,
or what we call deconstruction.
One of the questions I was occasionally asked was,
well, what&#39;s going to replace the encyclopedia
when Britannica no longer has a business model?
And it was a while before
the answer became manifest.
Now, of course, we know

what it is: it&#39;s the Wikipedia.
Now what&#39;s special about the
Wikipedia is not its distribution.
What&#39;s special about the Wikipedia
is the way it&#39;s produced.
The Wikipedia, of course, is an encyclopedia
created by its users.
And this, in fact, defines what you might call
the second decade of the Internet economy,
the decade in which the Internet as a noun
became the Internet as a verb.
It became a set of conversations,
the era in which user-generated
content and social networks
became the dominant phenomenon.
Now what that really meant
in terms of the Porter-Henderson framework
was the collapse of certain
kinds of economies of scale.
It turned out that tens of thousands
of autonomous individuals writing an encyclopedia
could do just as good a job,
and certainly a much cheaper job,
than professionals in a hierarchical organization.
So basically what was happening was that one layer
of this value chain was becoming fragmented,
as individuals could take over
where organizations were no longer needed.
But there&#39;s another question
that obviously this graph poses,
which is, okay, we&#39;ve
gone through two decades --
does anything distinguish the third?
And what I&#39;m going to argue is that indeed
something does distinguish the third,
and it maps exactly on to the kind of
Porter-Henderson logic that
we&#39;ve been talking about.
And that is, about data.
If we go back to around 2000,
a lot of people were talking
about the information revolution,
and it was indeed true that the world&#39;s stock of data
was growing, indeed growing quite fast.
but it was still at that point overwhelmingly analog.
We go forward to 2007,
not only had the world&#39;s stock of data exploded,
but there&#39;d been this massive substitution
of digital for analog.
And more important even than that,
if you look more carefully at this graph,
what you will observe is that about a half
of that digital data
is information that has an I.P. address.
It&#39;s on a server or it&#39;s on a P.C.
But having an I.P. address means that it
can be connected to any other data
that has an I.P. address.
It means it becomes possible
to put together half of the world&#39;s knowledge
in order to see patterns,
an entirely new thing.
If we run the numbers forward to today,
it probably looks something like this.
We&#39;re not really sure.
If we run the numbers forward to 2020,
we of course have an exact number, courtesy of IDC.
It&#39;s curious that the future is so much
more predictable than the present.
And what it implies is a hundredfold multiplication
in the stock of information that is connected
via an I.P. address.
Now, if the number of connections that we can make
is proportional to the number of pairs of data points,
a hundredfold multiplication in the quantity of data
is a ten-thousandfold multiplication
in the number of patterns
that we can see in that data,
this just in the last 10 or 11 years.
This, I would submit, is a sea change,
a profound change in the economics
of the world that we live in.
The first human genome,
that of James Watson,
was mapped as the culmination of the
Human Genome Project in the year 2000,
and it took about 200 million dollars
and about 10 years of work to map
just one person&#39;s genomic makeup.
Since then, the costs of mapping
the genome have come down.
In fact, they&#39;ve come down in recent years
very dramatically indeed,
to the point where the cost 
is now below 1,000 dollars,
and it&#39;s confidently predicted that by the year 2015
it will be below 100 dollars --
a five or six order of magnitude drop
in the cost of genomic mapping
in just a 15-year period,
an extraordinary phenomenon.
Now, in the days when mapping a genome
cost millions, or even tens of thousands,
it was basically a research enterprise.
Scientists would gather some representative people,
and they would see patterns, and they would try
and make generalizations about
human nature and disease
from the abstract patterns they find
from these particular selected individuals.
But when the genome can 
be mapped for 100 bucks,
99 dollars while you wait,
then what happens is, it becomes retail.
It becomes above all clinical.
You go the doctor with a cold,
and if he or she hasn&#39;t done it already,
the first thing they do is map your genome,
at which point what they&#39;re now doing
is not starting from some abstract 
knowledge of genomic medicine
and trying to work out how it applies to you,
but they&#39;re starting from your particular genome.
Now think of the power of that.
Think of where that takes us
when we can combine genomic data
with clinical data
with data about drug interactions
with the kind of ambient data that devices
like our phone and medical sensors
will increasingly be collecting.
Think what happens when we collect all of that data
and we can put it together
in order to find patterns we wouldn&#39;t see before.
This, I would suggest, perhaps it will take a while,
but this will drive a revolution in medicine.
Fabulous, lots of people talk about this.
But there&#39;s one thing that
doesn&#39;t get much attention.
How is that model of colossal sharing
across all of those kinds of databases
compatible with the business models
of institutions and organizations and corporations
that are involved in this business today?
If your business is based on proprietary data,
if your competitive advantage
is defined by your data,
how on Earth is that company or is that society
in fact going to achieve the value
that&#39;s implicit in the technology? They can&#39;t.
So essentially what&#39;s happening here,
and genomics is merely one example of this,
is that technology is driving
the natural scaling of the activity
beyond the institutional boundaries within which
we have been used to thinking about it,
and in particular beyond the institutional boundaries
in terms of which business strategy
as a discipline is formulated.
The basic story here is that what used to be
vertically integrated, oligopolistic competition
among essentially similar kinds of competitors
is evolving, by one means or another,
from a vertical structure to a horizontal one.
Why is that happening?
It&#39;s happening because
transaction costs are plummeting
and because scale is polarizing.
The plummeting of transaction costs
weakens the glue that holds value chains together,
and allows them to separate.
The polarization of scale economies
towards the very small -- small is beautiful --
allows for scalable communities
to substitute for conventional corporate production.
The scaling in the opposite direction,
towards things like big data,
drive the structure of business
towards the creation of new kinds of institutions
that can achieve that scale.
But either way, the typically vertical structure
gets driven to becoming more horizontal.
The logic isn&#39;t just about big data.
If we were to look, for example,
at the telecommunications industry,
you can tell the same story about fiber optics.
If we look at the pharmaceutical industry,
or, for that matter, university research,
you can say exactly the same story
about so-called &quot;big science.&quot;
And in the opposite direction,
if we look, say, at the energy sector,
where all the talk is about how households
will be efficient producers of green energy
and efficient conservers of energy,
that is, in fact, the reverse phenomenon.
That is the fragmentation of scale
because the very small can substitute
for the traditional corporate scale.
Either way, what we are driven to
is this horizontalization of the structure of industries,
and that implies fundamental changes
in how we think about strategy.
It means, for example, that we need to think
about strategy as the curation
of these kinds of horizontal structure,
where things like business definition
and even industry definition
are actually the outcomes of strategy,
not something that the strategy presupposes.
It means, for example, we need to work out
how to accommodate collaboration
and competition simultaneously.
Think about the genome.
We need to accommodate the very large
and the very small simultaneously.
And we need industry structures
that will accommodate very,
very different motivations,
from the amateur motivations
of people in communities
to maybe the social motivations
of infrastructure built by governments,
or, for that matter, cooperative institutions
built by companies that are otherwise competing,
because that is the only way
that they can get to scale.
These kinds of transformations
render the traditional premises 
of business strategy obsolete.
They drive us into a completely new world.
They require us, whether we are
in the public sector or the private sector,
to think very fundamentally differently
about the structure of business,
and, at last, it makes strategy interesting again.
Thank you.

(Applause)

