
Design is a slippery
and elusive phenomenon,
which has meant different
things at different times.
But all truly inspiring design projects

have one thing in common:
they began with a dream.
And the bolder the dream,
the greater the design feat
that will be required to achieve it.
And this is why the greatest
designers are almost always
the biggest dreamers
and rebels and renegades.
This has been the case throughout history,
all the way back to the year 300 BC,
when a 13-year-old became the king
of a remote, very poor
and very small Asian country.
He dreamt of acquiring land,
riches and power
through military conquest.
And his design skills --
improbable though it sounds --
would be essential
in enabling him to do so.
At the time,
all weapons were made by hand
to different specifications.
So if an archer ran out
of arrows during a battle,
they wouldn&#39;t necessarily be able
to fire another archer&#39;s arrows
from their bow.
This of course meant that they would
be less effective in combat
and very vulnerable, too.
Ying solved this problem
by insisting that all bows and arrows
were designed identically,
so they were interchangeable.
And he did the same for daggers,
axes, spears, shields
and every other form of weaponry.
His formidably equipped army
won batter after battle,
and within 15 years,
his tiny kingdom had
succeeded in conquering
all its larger, richer,
more powerful neighbors,
to found the mighty Chinese Empire.
Now, no one, of course,
would have thought of describing
Ying Zheng as a designer at the time --
why would they?
And yet he used design
unknowingly and instinctively
but with tremendous ingenuity
to achieve his ends.
And so did another equally
improbable, accidental designer,
who was also not above using
violence to get what he wanted.
This was Edward Teach, better known
as the British pirate, Blackbeard.
This was the golden age of piracy,
where pirates like Teach
were terrorizing the high seas.
Colonial trade was flourishing,
and piracy was highly profitable.
And the smarter pirates like him
realized that to maximize their spoils,
they needed to attack
their enemies so brutally
that they would surrender on sight.
So in other words,
they could take the ships
without wasting ammunition,
or incurring casualties.
So Edward Teach redesigned
himself as Blackbeard
by playing the part of a merciless brute.
He wore heavy jackets and big hats
to accentuate his height.
He grew the bushy black beard
that obscured his face.
He slung braces of pistols
on either shoulder.
He even attached matches to the brim
of his hat and set them alight,
so they sizzled menacingly
whenever his ship was poised to attack.
And like many pirates of that era,
he flew a flag that bore
the macabre symbols
of a human skull
and a pair of crossed bones,
because those motifs had signified death
in so many cultures for centuries,
that their meaning
was instantly recognizable,
even in the lawless, illiterate

world of the high seas:
surrender or you&#39;ll suffer.
So of course, all his sensible
victims surrendered on sight.
Put like that,
it&#39;s easy to see why Edward Teach
and his fellow pirates
could be seen as pioneers
of modern communications design,
and why their deadly symbol --

(Laughter)

there&#39;s more --
why their deadly symbol
of the skull and crossbones
was a precursor of today&#39;s logos,
rather like the big red letters
standing behind me,
but of course with a different message.

(Laughter)

Yet design was also used to nobler ends
by an equally brilliant and equally
improbable designer,
the 19th-century British nurse,
Florence Nightingale.
Her mission was to provide
decent healthcare for everyone.
Nightingale was born into a rather
grand, very wealthy British family,
who were horrified when she volunteered
to work in military hospitals
during the Crimean War.
Once there, she swiftly realized
that more patients were dying
of infections that they caught there,
in the filthy, fetid wards,
than they were of battle wounds.
So she campaigned
for cleaner, lighter, airier clinics
to be designed and built.
Back in Britain,
she mounted another campaign,
this time for civilian hospitals,
and insisted that the same design
principles were applied to them.
The Nightingale ward, as it is called,
dominated hospital design
for decades to come,
and elements of it are still used today.
But by then,
design was seen as a tool
of the Industrial Age.
It was formalized and professionalized,
but it was restricted to specific roles
and generally applied in pursuit
of commercial goals
rather than being used intuitively,
as Florence Nightingale, Blackbeard
and Ying Zheng had done.
By the 20th century,
this commercial ethos was so powerful,
that any designers who deviated from it
risked being seen as cranks
or subversives.
Now among them is one
of my great design heroes,
the brilliant László Moholy-Nagy.
He was the Hungarian artist and designer
whose experiments with the impact
of technology on daily life
were so powerful
that they still influence
the design of the digital images
we see on our phone and computer screens.
He radicalized the Bauhaus Design
School in 1920s Germany,
and yet some of his former
colleagues shunned him
when he struggled to open a new
Bauhaus in Chicago years later.
Moholy&#39;s ideas were as bold
and incisive as ever,
but his approach to design
was too experimental,
as was his insistence
on seeing it, as he put it,
as an attitude, not a profession
to be in tune with the times.
And sadly, the same applied

to another design maverick:
Richard Buckminster Fuller.
He was yet another
brilliant design visionary
and design activist,
who was completely committed
to designing a sustainable society
in such a forward-thinking way
that he started talking about
the importance of environmentalism
in design in the 1920s.
Now he, despite his efforts,
was routinely mocked as a crank
by many in the design establishment,
and admittedly,
some of his experiments failed,
like the flying car
that never got off the ground.
And yet, the geodesic dome,
his design formula to build
an emergency shelter
from scraps of wood, metal, plastic,
bits of tree, old blankets,
plastic sheeting --
just about anything
that&#39;s available at the time --
is one of the greatest feats
of humanitarian design,
and has provided sorely needed refuge
to many, many people
in desperate circumstances
ever since.
Now, it was the courage
and verve of radical designers
like Bucky and Moholy
that drew me to design.
I began my career as a news journalist
and foreign correspondent.
I wrote about politics, economics
and corporate affairs,
and I could have chosen
to specialize in any of those fields.
But I picked design,
because I believe it&#39;s one of the most
powerful tools at our disposal
to improve our quality of life.
Thank you, fellow TED design buffs.

(Applause)

And greatly as I admire the achievements
of professional designers,
which have been extraordinary and immense,
I also believe
that design benefits hugely
from the originality,
the lateral thinking
and the resourcefulness
of its rebels and renegades.
And we&#39;re living at a remarkable
moment in design,
because this is a time when the two camps
are coming closer together.
Because even very basic advances
in digital technology
have enabled them to operate
increasingly independently,
in or out of a commercial context,
to pursue ever more ambitious
and eclectic objectives.
So in theory,
basic platforms like crowdfunding,
cloud computing, social media
are giving greater freedom
to professional designers
and giving more resources
for the improvisational ones,
and hopefully,
a more receptive response to their ideas.
Now, some of my favorite
examples of this are in Africa,
where a new generation of designers
are developing incredible
Internet of Things technologies
to fulfill Florence Nightingale&#39;s dream
of improving healthcare
in countries where more people
now have access to cell phones
than to clean, running water.
And among them is Arthur Zang.
He&#39;s a young, Cameroonian design engineer
who has a adapted a tablet
computer into the Cardiopad,
a mobile heart-monitoring device.
It can be used to monitor the hearts
of patients in remote, rural areas.
The data is then sent
on a cellular network
to well-equipped hospitals
hundreds of miles away
for analysis.
And if any problems are spotted
by the specialists there,
a suitable course of treatment
is recommended.
And this of course saves many patients
from making long, arduous, expensive
and often pointless journeys
to those hospitals,
and makes it much, much likelier
that their hearts
will actually be checked.
Arthur Zang started working
on the Cardiopad eight years ago,
in his final year at university.
But he failed to persuade
any conventional sources
to give him investment to get
the project off the ground.
He posted the idea on Facebook,
where a Cameroonian
government official saw it
and managed to secure
a government grant for him.
He&#39;s now developing
not only the Cardiopad,
but other mobile medical devices
to treat different conditions.
And he isn&#39;t alone,
because there are many other
inspiring and enterprising designers
who are also pursuing
extraordinary projects of their own.
And I&#39;m going to finish
by looking at just a few of them.
One is Peek Vision.
This is a group of doctors
and designers in Kenya,
who&#39;ve developed an Internet of Things
technology of their own,
as a portable eye examination kit.
Then there&#39;s Gabriel Maher,
who is developing a new design language
to enable us to articulate the subtleties
of our changing gender identities,
without recourse
to traditional stereotypes.
All of these designers and many more
are pursuing their dreams,
by the making the most
of their newfound freedom,
with the discipline
of professional designers
and the resourcefulness
of rebels and renegades.
And we all stand to benefit.
Thank you.

(Applause)

