
Today I want to talk to you
about ethnic conflict
and civil war.
These are not normally the most cheerful of topics,
nor do they generally generate
the kind of good news
that this conference is about.
Yet, not only is there at least some good news
to be told about fewer such conflicts now
than two decades ago,
but what is perhaps more important
is that we also have come
to a much better understanding of what can be done
to further reduce the number
of ethnic conflicts and civil wars
and the suffering that they inflict.

Three things stand out:
leadership, diplomacy
and institutional design.
What I will focus on in my talk
is why they matter, how they matter,
and what we can all do
to make sure that they continue to matter
in the right ways,
that is, how all of us can contribute
to developing and honing the skills
of local and global leaders
to make peace
and to make it last.
But let&#39;s start at the beginning.
Civil wars have made news headlines
for many decades now,
and ethnic conflicts in particular
have been a near constant presence
as a major international security threat.
For nearly two decades now,
the news has been bad
and the images have been haunting.
In Georgia, after years of stalemate,
we saw a full-scale resurgence of violence
in August, 2008.
This quickly escalated into a five-day war
between Russia and Georgia,
leaving Georgia ever more divided.
In Kenya, contested presidential elections in 2007 --
we just heard about them --
quickly led to high levels
of inter-ethnic violence
and the killing and displacement
of thousands of people.
In Sri Lanka,
a decades-long civil war
between the Tamil minority
and the Sinhala majority
led to a bloody climax in 2009,
after perhaps as many as 100,000
people had been killed
since 1983.
In Kyrgyzstan, just over the last few weeks,
unprecedented levels of violence occurred
between ethnic Kyrgyz
and ethnic Uzbeks.
Hundreds have been killed,
and more than 100,000 displaced,
including many ethnic Uzbeks
who fled to neighboring Uzbekistan.
In the Middle East,
conflict between Israelis and Palestinians
continues unabated,
and it becomes ever more difficult
to see how, just how
a possible, sustainable solution
can be achieved.
Darfur may have slipped from the news headlines,
but the killing and displacement there
continues as well,
and the sheer human misery that it creates
is very hard to fathom.
And in Iraq, finally,
violence is on the rise again,
and the country has yet to form a government
four months after
its last parliamentary elections.
But hang on, this talk is to be about the good news.
So are these now the images of the past?
Well, notwithstanding the gloomy pictures
from the Middle East, Darfur,
Iraq, elsewhere,
there is a longer-term trend
that does represent some good news.
Over the past two decades, since the end of the Cold War,
there has been an overall decline
in the number of civil wars.
Since the high in the early 1990s,
with about 50 such civil wars ongoing,
we now have 30 percent fewer
such conflicts today.
The number of people killed in civil wars
also is much lower today
than it was a decade ago or two.
But this trend is less unambiguous.
The highest level of deaths on the battlefield
was recorded between 1998 and 2001,
with about 80,000 soldiers, policemen and rebels
killed every year.
The lowest number of combatant casualties
occurred in 2003,
with just 20,000 killed.
Despite the up and down since then,
the overall trend --
and this is the important bit --
clearly points downward
for the past two decades.
The news about civilian casualties
is also less bad than it used to be.
From over 12,000 civilians
deliberately killed in civil wars
in 1997 and 1998,
a decade later,
this figure stands at 4,000.
This is a decrease by two-thirds.
This decline would be even more obvious
if we factored in the genocide in Rwanda
in 1994.
But then 800,000 civilians were slaughtered
in a matter of just a few months.
This certainly is an accomplishment
that must never be surpassed.
What is also important is to note
that these figures only tell part of the story.
They exclude people
that died as a consequence of civil war,
from hunger or disease, for example.
And they also do not properly account
for civilian suffering more generally.
Torture, rape and ethnic cleansing
have become highly effective,
if often non-lethal, weapons in civil war.
To put it differently,
for the civilians that suffer the consequences
of ethnic conflict and civil war,
there is no good war
and there is no bad peace.
Thus, even though every civilian killed,
maimed, raped, or tortured is one too many,
the fact that the number
of civilian casualties
is clearly lower today
than it was a decade ago,
is good news.
So, we have fewer conflicts today
in which fewer people get killed.
And the big question, of course,
is why?
In some cases,
there is a military victory of one side.
This is a solution of sorts,
but rarely is it one
that comes without human costs
or humanitarian consequences.
The defeat of the Tamil Tigers in Sri Lanka
is perhaps the most recent example of this,
but we have seen similar
so-called military solutions
in the Balkans, in the South Caucasus
and across most of Africa.
At times, they are complimented
by negotiated settlements,
or at least cease-fire agreements,
and peacekeepers are deployed.
But hardly ever do they represent
a resounding success --
Bosnia and Herzegovina
perhaps more so than Georgia.
But for many parts of Africa,
a colleague of mine once put it this way,
&quot;The cease-fire on Tuesday night
was reached just in time
for the genocide to start on Wednesday morning.&quot;
But let&#39;s look at the good news again.
If there&#39;s no solution on the battlefield,
three factors can account
for the prevention of ethnic conflict and civil war,

or for sustainable peace afterwards:
leadership, diplomacy
and institutional design.
Take the example of Northern Ireland.
Despite centuries of animosity,
decades of violence
and thousands of people killed,
1998 saw the conclusion
of an historic agreement.
Its initial version was skillfully mediated
by Senator George Mitchell.
Crucially, for the long-term success
of the peace process in Northern Ireland,
he imposed very clear conditions
for the participation and negotiations.
Central among them,
a commitment
to exclusively peaceful means.
Subsequent revisions of the agreement
were facilitated by the British and Irish governments,
who never wavered in their determination
to bring peace and stability to Northern Ireland.
The core institutions
that were put in place in 1998
and their modifications
in 2006 and 2008
were highly innovative
and allowed all conflict parties
to see their core concerns and demands addressed.
The agreement combines a power-sharing arrangement
in Northern Ireland
with cross-border institutions
that link Belfast and Dublin
and thus recognizes
the so-called Irish dimension of the conflict.
And significantly,
there&#39;s also a clear focus
on both the rights of individuals
and the rights of communities.
The provisions in the agreement may be complex,
but so is the underlying conflict.
Perhaps most importantly,
local leaders repeatedly rose to the challenge of compromise,
not always fast
and not always enthusiastically,
but rise in the end they did.
Who ever could have imagined
Ian Paisley and Martin McGuinness
jointly governing Northern Ireland
as First and Deputy First Minister?
But then, is Northern Ireland a unique example,
or does this kind of explanation
only hold more generally
in democratic and developed countries?
By no means.
The ending of Liberia&#39;s long-lasting civil war
in 2003
illustrates the importance
of leadership, diplomacy
and institutional design
as much as the successful prevention
of a full-scale civil war
in Macedonia in 2001,
or the successful ending
of the conflict in Aceh in Indonesia in 2005.
In all three cases,
local leaders were willing and able
to make peace,
the international community stood ready
to help them negotiate and implement an agreement,
and the institutions have lived up
to the promise that they held
on the day they were agreed.
Focusing on leadership, diplomacy
and institutional design
also helps explain failures to achieve peace,
or to make it last.
The hopes that were vested in the Oslo Accords
did not lead to an end
of the Israeli/Palestinian conflict.
Not all the issues that needed to be resolved
were actually covered in the agreements.
Rather, local leaders committed
to revisiting them later on.
Yet instead of grasping this opportunity,
local and international leaders
soon disengaged
and became distracted
by the second Intifada, the events of 9/11
and the wars in Afghanistan and Iraq.
The comprehensive peace agreement for Sudan
signed in 2005
turned out to be less comprehensive than envisaged,
and its provisions may yet bear the seeds
of a full-scale return to war
between north and south.
Changes and shortcomings in leadership,
more off than on international diplomacy
and institutional failures
account for this
in almost equal measure.
Unresolved boundary issues, squabbles over oil revenues,
the ongoing conflict in Darfur,
escalating tribal violence in the south
and generally weak state capacity
across all of Sudan
complete a very depressing picture
of the state of affairs
in Africa&#39;s largest country.

A final example: Kosovo.
The failure to achieve
a negotiated solution for Kosovo
and the violence, tension
and de facto partition that resulted from it
have their reasons
in many, many different factors.
Central among them are three.
First, the intransigence of local leaders
to settle for nothing less
than their maximum demands.
Second, an international diplomatic effort
that was hampered from the beginning
by Western support for Kosovo&#39;s independence.
And third, a lack of imagination
when it came to designing institutions
that could have addressed the concerns
of Serbs and Albanians alike.
By the same token --
and here we have some good news again --
the very fact that there is a high-level,
well-resourced international presence
in Kosovo
and the Balkans region more generally
and the fact that local leaders on both sides
have showed relative restraint,
explains why things have not been worse
over the past two years since 2008.
So even in situations
where outcomes are less than optimal,
local leaders
and international leaders have a choice,
and they can make a difference for the better.
A cold war
is not as good
as a cold peace,
but a cold peace
is still better than a hot war.
Good news is also about learning the right lesson.
So what then distinguishes
the Israeli/Palestinian conflict
from that in Northern Ireland,
or the civil war in Sudan
from that in Liberia?
Both successes and failures
teach us several critically important things
that we need to bear in mind
if we want the good news to continue.
First, leadership.
In the same way in which ethnic conflict and civil war
are not natural
but man-made disasters,
their prevention and settlement
does not happen automatically either.
Leadership needs to be capable,
determined and visionary
in its commitment to peace.
Leaders need to connect to each other
and to their followers,
and they need to bring them along
on what is an often arduous journey
into a peaceful future.
Second, diplomacy.
Diplomacy needs to be well resourced,
sustained,
and apply the right mix of incentives and pressures
on leaders and followers.
It needs to help them reach an equitable compromise,
and it needs to ensure
that a broad coalition
of local, regional
and international supporters
help them implement their agreement.
Third, institutional design.
Institutional design requires
a keen focus on issues,
innovative thinking
and flexible and well-funded implementation.
Conflict parties need to move away
from maximum demands
and towards a compromise
that recognizes each other&#39;s needs.
And they need to think
about the substance of their agreement
much more than about
the labels they want to attach to them.
Conflict parties also need to be prepared
to return to the negotiation table
if the agreement implementation stalls.
For me personally,

the most critical lesson of all is this:
Local commitment to peace
is all-important,
but it is often not enough
to prevent or end violence.
Yet, no amount of diplomacy
or institutional design
can make up for local failures
and the consequences that they have.
Therefore, we must invest
in developing leaders,
leaders that have the skills,
vision and determination
to make peace.
Leaders, in other words,
that people will trust
and that they will want to follow
even if that means
making hard choices.

A final thought:
Ending civil wars
is a process that is fraught with dangers,
frustrations and setbacks.
It often takes a generation to accomplish,
but it also requires us, today&#39;s generation,
to take responsibility
and to learn the right lessons
about leadership, diplomacy
and institutional design,
so that the child soldiers of today
can become the children of tomorrow.
Thank you.

(Applause)

