
Almost a year ago,
my aunt started suffering back pains.
She went to see the doctor
and they told her it was a normal injury
for someone who had been playing tennis
for almost 30 years.
They recommended that she do some therapy,
but after a while she wasn&#39;t feeling better,
so the doctors decided to do further tests.
They did an x-ray
and discovered an injury in her lungs,
and at the time they thought that the injury
was a strain in the muscles and tendons
between her ribs,
but after a few weeks of treatment,
again her health wasn&#39;t getting any better.
So finally, they decided to do a biopsy,
and two weeks later,
the results of the biopsy came back.
It was stage 3 lung cancer.
Her lifestyle was almost free of risk.
She never smoked a cigarette,
she never drank alcohol,
and she had been playing sports
for almost half her life.
Perhaps, that is why it took them almost six months
to get her properly diagnosed.
My story might be, unfortunately,
familiar to most of you.
One out of three people sitting in this audience
will be diagnosed with some type of cancer,
and one out of four
will die because of it.
Not only did that cancer diagnosis
change the life of our family,
but that process of going
back and forth with new tests,
different doctors describing symptoms,
discarding diseases over and over,
was stressful and frustrating,
especially for my aunt.
And that is the way cancer diagnosis has been done
since the beginning of history.
We have 21st-century medical treatments and drugs
to treat cancer,
but we still have 20th-century procedures
and processes for diagnosis, if any.
Today, most of us have to wait for symptoms
to indicate that something is wrong.
Today, the majority of people still don&#39;t have access
to early cancer detection methods,
even though we know
that catching cancer early
is basically the closest thing we have
to a silver bullet cure against it.
We know that we can change this in our lifetime,
and that is why my team and I
have decided to begin this journey,
this journey to try to make cancer detection
at the early stages
and monitoring the appropriate 
response at the molecular level
easier, cheaper, smarter
and more accessible than ever before.
The context, of course,
is that we&#39;re living at a time
where technology is disrupting our present
at exponential rates,
and the biological realm is no exception.
It is said today that biotech is advancing
at least six times faster than the growth rate
of the processing power of computers.
But progress in biotech
is not only being accelerated,
it is also being democratized.
Just as personal computers or the Internet
or smartphones leveled the playing field
for entrepreneurship, politics or education,
recent advances have leveled it
up for biotech progress as well,
and that is allowing
multidisciplinary teams like ours
to try to tackle and look at these problems
with new approaches.
We are a team of scientists and technologists
from Chile, Panama,
Mexico, Israel and Greece,
and based on recent scientific discoveries,
we believe that we have found
a reliable and accurate way
of detecting several types of cancer
at the very early stages through a blood sample.
We do it by detecting a set of very small molecules
that circulate freely in our blood
called microRNAs.
To explain what microRNAs are
and their important role in cancer,
I need to start with proteins,
because when cancer is present in our body,
protein modification is observed
in all cancerous cells.
As you might know,
proteins are large biological molecules
that perform different functions within our body,
like catalyzing metabolic reactions
or responding to stimuli
or replicating DNA,
but before a protein is expressed or produced,
relevant parts of its genetic code
present in the DNA
are copied into the messenger RNA,
so this messenger RNA
has instructions on how to build a specific protein,
and potentially it can build hundreds of proteins,
but the one that tells them when to build them
and how many to build
are microRNAs.
So microRNAs are small molecules
that regulate gene expression.
Unlike DNA, which is mainly fixed,
microRNAs can vary depending on internal
and environmental conditions at any given time,
telling us which genes are actively 
expressed at that particular moment.
And that is what makes microRNAs
such a promising biomarker for cancer,
because as you know,
cancer is a disease of altered gene expression.
It is the uncontrolled regulation of genes.
Another important thing to consider
is that no two cancers are the same,
but at the microRNA level, there are patterns.
Several scientific studies have shown
that abnormal microRNA expression levels
varies and creates a unique, specific pattern
for each type of cancer,
even at the early stages,
reflecting the progression of the disease,
and whether it&#39;s responding to medication
or in remission,
making microRNAs a perfect,
highly sensitive biomarker.
However, the problem with microRNAs
is that we cannot use existing DNA-based technology
to detect them in a reliable way,
because they are very short sequences of nucleotides,
much smaller than DNA.
And also, all microRNAs are
very similar to each other,
with just tiny differences.
So imagine trying to differentiate two molecules,
extremely similar, extremely small.
We believe that we have found a way to do so,
and this is the first time that we&#39;ve shown it in public.
Let me do a demonstration.
Imagine that next time you go to your doctor
and do your next standard blood test,
a lab technician extracts a total RNA,
which is quite simple today,
and puts it in a standard 
96-well plate like this one.
Each well of these plates
has specific biochemistry that we assign,
that is looking for a specific microRNA,
acting like a trap that closes
only when the microRNA is present in the sample,
and when it does, it will shine with green color.
To run the reaction,
you put the plate inside a device like this one,
and then you can put your smartphone on top of it.
If we can have a camera here
so you can see my screen.
A smartphone is a connected computer
and it&#39;s also a camera,
good enough for our purpose.
The smartphone is taking pictures,
and when the reaction is over,
it will send the pictures
to our online database for processing
and interpretation.
This entire process lasts around 60 minutes,
but when the process is over,
wells that shine are matched 
with the specific microRNAs
and analyzed in terms of how much and how fast
they shine.
And then, when this entire process is over,
this is what happens.
This chart is showing the specific microRNAs
present in this sample
and how they reacted over time.
Then, if we take this specific pattern of microRNA
of this person&#39;s samples
and compare it with existing scientific documentation
that correlates microRNA patterns
with a specific presence of a disease,
this is how pancreatic cancer looks like.
This inside is a real sample
where we just detected pancreatic cancer.

(Applause)

Another important aspect of this approach
is the gathering and mining of data in the cloud,
so we can get results in real time
and analyze them with our contextual information.
If we want to better understand
and decode diseases like cancer,
we need to stop treating them
as acute, isolated episodes,
and consider and measure everything
that affects our health on a permanent basis.
This entire platform is a working prototype.
It uses state-of-the-art molecular biology,
a low-cost, 3D-printed device,
and data science
to try to tackle one of humanity&#39;s 
toughest challenges.
Since we believe early cancer detection
should really be democratized,
this entire solution costs at least 50 times less
than current available methods,
and we know that the community can help us
accelerate this even more,
so we&#39;re making the design of the device
open-source.

(Applause)

Let me say very clearly
that we are at the very early stages,
but so far, we have been able
to successfully identify the microRNA pattern
of pancreatic cancer, lung cancer,
breast cancer and hepatic cancer.
And currently, we&#39;re doing a clinical trial
in collaboration with the
German Cancer Research Center
with 200 women for breast cancer.

(Applause)

This is the single non-invasive,
accurate and affordable test
that has the potential to dramatically change
how cancer procedures and diagnostics
have been done.
Since we&#39;re looking for the microRNA patterns
in your blood at any given time,
you don&#39;t need to know
which cancer you&#39;re looking for.
You don&#39;t need to have any symptoms.
You only need one milliliter of blood
and a relatively simple array of tools.
Today, cancer detection happens mainly
when symptoms appear.
That is, at stage 3 or 4,
and I believe that is too late.
It is too expensive for our families.
It is too expensive for humanity.
We cannot lose the war against cancer.
It not only costs us billions of dollars,
but it also costs us the people we love.
Today, my aunt, she&#39;s fighting bravely
and going through this process
with a very positive attitude.
However, I want fights like this
to become very rare.
I want to see the day
when cancer is treated easily
because it can be routinely diagnosed
at the very early stages,
and I&#39;m certain
that in the very near future,
because of this
and other breakthroughs that we are seeing
every day in the life sciences,
the way we see cancer
will radically change.
It will give us the chance of detecting it early,
understanding it better,
and finding a cure.
Thank you very much.

(Applause)

