
In the space that used
to house one transistor,
we can now fit one billion.
That made it so that a computer
the size of an entire room
now fits in your pocket.
You might say the future is small.
As an engineer,
I&#39;m inspired by this miniaturization
revolution in computers.
As a physician,
I wonder whether we could use it
to reduce the number of lives lost
due to one of the fastest-growing

diseases on Earth:
cancer.
Now when I say that,
what most people hear me say
is that we&#39;re working on curing cancer.
And we are.
But it turns out
that there&#39;s an incredible
opportunity to save lives
through the early detection
and prevention of cancer.
Worldwide, over two-thirds of deaths
due to cancer are fully preventable
using methods that we already
have in hand today.
Things like vaccination, timely screening
and of course, stopping smoking.
But even with the best tools
and technologies that we have today,
some tumors can&#39;t be detected
until 10 years after
they&#39;ve started growing,
when they are 50 million
cancer cells strong.
What if we had better technologies
to detect some of these more
deadly cancers sooner,
when they could be removed,
when they were just getting started?
Let me tell you about how
miniaturization might get us there.
This is a microscope in a typical lab
that a pathologist would use
for looking at a tissue specimen,
like a biopsy or a pap smear.
This $7,000 microscope
would be used by somebody
with years of specialized training
to spot cancer cells.
This is an image from a colleague
of mine at Rice University,
Rebecca Richards-Kortum.
What she and her team have done
is miniaturize that whole microscope
into this $10 part,
and it fits on the end
of an optical fiber.
Now what that means is instead
of taking a sample from a patient
and sending it to the microscope,
you can bring the microscope
to the patient.
And then, instead of requiring
a specialist to look at the images,
you can train the computer to score
normal versus cancerous cells.
Now this is important,
because what they found
working in rural communities,
is that even when they have
a mobile screening van
that can go out into the community
and perform exams
and collect samples
and send them to the central
hospital for analysis,
that days later,
women get a call
with an abnormal test result
and they&#39;re asked to come in.
Fully half of them don&#39;t turn up
because they can&#39;t afford the trip.
With the integrated microscope
and computer analysis,
Rebecca and her colleagues
have been able to create a van
that has both a diagnostic setup
and a treatment setup.
And what that means
is that they can do a diagnosis
and perform therapy on the spot,
so no one is lost to follow up.
That&#39;s just one example of how
miniaturization can save lives.
Now as engineers,
we think of this
as straight-up miniaturization.
You took a big thing
and you made it little.
But what I told you before about computers
was that they transformed our lives
when they became small enough
for us to take them everywhere.
So what is the transformational
equivalent like that in medicine?
Well, what if you had a detector
that was so small that it could
circulate in your body,
find the tumor all by itself
and send a signal to the outside world?
It sounds a little bit
like science fiction.
But actually, nanotechnology
allows us to do just that.
Nanotechnology allows us to shrink
the parts that make up the detector
from the width of a human hair,
which is 100 microns,
to a thousand times smaller,
which is 100 nanometers.
And that has profound implications.
It turns out that materials
actually change their properties
at the nanoscale.
You take a common material like gold,
and you grind it into dust,
into gold nanoparticles,
and it changes from looking
gold to looking red.
If you take a more exotic material
like cadmium selenide --
forms a big, black crystal --
if you make nanocrystals
out of this material
and you put it in a liquid,
and you shine light on it,
they glow.
And they glow blue, green,
yellow, orange, red,
depending only on their size.
It&#39;s wild! Can you imagine an object
like that in the macro world?
It would be like all the denim jeans
in your closet are all made of cotton,
but they are different colors
depending only on their size.

(Laughter)

So as a physician,
what&#39;s just as interesting to me
is that it&#39;s not just
the color of materials
that changes at the nanoscale;
the way they travel
in your body also changes.
And this is the kind of observation
that we&#39;re going to use
to make a better cancer detector.
So let me show you what I mean.
This is a blood vessel in the body.
Surrounding the blood vessel is a tumor.
We&#39;re going to inject nanoparticles
into the blood vessel
and watch how they travel
from the bloodstream into the tumor.
Now it turns out that the blood vessels
of many tumors are leaky,
and so nanoparticles can leak out
from the bloodstream into the tumor.
Whether they leak out
depends on their size.
So in this image,
the smaller, hundred-nanometer,
blue nanoparticles are leaking out,
and the larger, 500-nanometer,
red nanoparticles
are stuck in the bloodstream.
So that means as an engineer,
depending on how big
or small I make a material,
I can change where it goes in your body.
In my lab, we recently made
a cancer nanodetector
that is so small that it could travel
into the body and look for tumors.
We designed it to listen

for tumor invasion:
the orchestra of chemical signals
that tumors need to make to spread.
For a tumor to break out
of the tissue that it&#39;s born in,
it has to make chemicals called enzymes
to chew through
the scaffolding of tissues.
We designed these nanoparticles
to be activated by these enzymes.
One enzyme can activate a thousand
of these chemical reactions in an hour.
Now in engineering, we call
that one-to-a-thousand ratio
a form of amplification,
and it makes something ultrasensitive.
So we&#39;ve made an ultrasensitive
cancer detector.
OK, but how do I get this activated
signal to the outside world,
where I can act on it?
For this, we&#39;re going to use
one more piece of nanoscale biology,
and that has to do with the kidney.
The kidney is a filter.
Its job is to filter out the blood
and put waste into the urine.
It turns out that what the kidney filters
is also dependent on size.
So in this image, what you can see
is that everything smaller
than five nanometers
is going from the blood,
through the kidney, into the urine,
and everything else
that&#39;s bigger is retained.
OK, so if I make a 100-nanometer
cancer detector,
I inject it in the bloodstream,
it can leak into the tumor
where it&#39;s activated by tumor enzymes
to release a small signal
that is small enough to be
filtered out of the kidney
and put into the urine,
I have a signal in the outside world
that I can detect.
OK, but there&#39;s one more problem.
This is a tiny little signal,
so how do I detect it?
Well, the signal is just a molecule.
They&#39;re molecules
that we designed as engineers.
They&#39;re completely synthetic,
and we can design them
so they are compatible
with our tool of choice.
If we want to use a really
sensitive, fancy instrument
called a mass spectrometer,
then we make a molecule
with a unique mass.
Or maybe we want make something
that&#39;s more inexpensive and portable.
Then we make molecules
that we can trap on paper,
like a pregnancy test.
In fact, there&#39;s a whole
world of paper tests
that are becoming available
in a field called paper diagnostics.
Alright, where are we going with this?
What I&#39;m going to tell you next,
as a lifelong researcher,
represents a dream of mine.
I can&#39;t say that&#39;s it&#39;s a promise;
it&#39;s a dream.
But I think we all have to have dreams
to keep us pushing forward,
even -- and maybe especially --
cancer researchers.
I&#39;m going to tell you what I hope
will happen with my technology,
that my team and I will put
our hearts and souls
into making a reality.
OK, here goes.
I dream that one day,
instead of going into
an expensive screening facility
to get a colonoscopy,
or a mammogram,
or a pap smear,
that you could get a shot,
wait an hour,
and do a urine test on a paper strip.
I imagine that this could even happen
without the need for steady electricity,
or a medical professional in the room.
Maybe they could be far away
and connected only by the image
on a smartphone.
Now I know this sounds like a dream,
but in the lab we already
have this working in mice,
where it works better
than existing methods
for the detection of lung,
colon and ovarian cancer.
And I hope that what this means
is that one day we can
detect tumors in patients
sooner than 10 years
after they&#39;ve started growing,
in all walks of life,
all around the globe,
and that this would lead
to earlier treatments,
and that we could save more lives
than we can today,
with early detection.
Thank you.

(Applause)

