
For much of the past century,
architecture was under the spell
of a famous doctrine.
&quot;Form follows function&quot; had become
modernity&#39;s ambitious manifesto
and detrimental straitjacket,
as it liberated architecture
from the decorative,
but condemned it to utilitarian rigor
and restrained purpose.
Of course, architecture is about function,
but I want to remember a rewriting
of this phrase by Bernard Tschumi,
and I want to propose
a completely different quality.
If form follows fiction,
we could think of architecture
and buildings as a space of stories --
stories of the people that live there,
of the people that work
in these buildings.
And we could start to imagine
the experiences our buildings create.
In this sense, I&#39;m interested in fiction
not as the implausible but as the real,
as the reality of what architecture means
for the people that live
in it and with it.
Our buildings are prototypes,
ideas for how the space of living
or how the space of working
could be different,
and what a space of culture
or a space of media could look like today.
Our buildings are real;
they&#39;re being built.
They&#39;re an explicit engagement
in physical reality
and conceptual possibility.
I think of our architecture
as organizational structures.
At their core is indeed

structural thinking, like a system:
How can we arrange things
in both a functional
and experiential way?
How can we create structures
that generate a series
of relationships and narratives?
And how can fictive stories
of the inhabitants and users
of our buildings
script the architecture,
while the architecture scripts
those stories at the same time?
And here comes the second term into play,
what I call &quot;narrative hybrids&quot; --
structures of multiple
simultaneous stories
that unfold throughout
the buildings we create.
So we could think of architecture
as complex systems of relationships,
both in a programmatic and functional way
and in an experiential
and emotive or social way.
This is the headquarters
for China&#39;s national broadcaster,
which I designed together
with Rem Koolhaas at OMA.
When I first arrived in Beijing in 2002,

the city planners showed us this image:
a forest of several hundred skyscrapers
to emerge in the central
business district,
except at that time,
only a handful of them existed.
So we had to design in a context
that we knew almost nothing about,

except one thing:
it would all be about verticality.
Of course, the skyscraper is vertical --
it&#39;s a profoundly hierarchical structure,
the top always the best,
the bottom the worst,
and the taller you are,
the better, so it seems.
And we wanted to ask ourselves,
could a building be about
a completely different quality?
Could it undo this hierarchy,
and could it be about a system
that is more about collaboration,
rather than isolation?
So we took this needle
and bent it back into itself,
into a loop of interconnected activities.
Our idea was to bring all aspects
of television-making

into one single structure: news,
program production, broadcasting,
research and training, administration --
all into a circuit
of interconnected activities
where people would meet in a process
of exchange and collaboration.
I still very much like this image.
It reminds one of biology classes,
if you remember the human body
with all its organs
and circulatory systems, like at school.
And suddenly you think of architecture
no longer as built substance,
but as an organism, as a life form.
And as you start to dissect this organism,
you can identify a series
of primary technical clusters --
program production,
broadcasting center and news.
Those are tightly intertwined

with social clusters:
meeting rooms, canteens, chat areas --
informal spaces for people
to meet and exchange.
So the organizational structure
of this building was a hybrid
between the technical and the social,
the human and the performative.
And of course, we used the loop
of the building as a circulatory system,
to thread everything together
and to allow both visitors and staff
to experience all these different
functions in a great unity.
With 473,000 square meters,
it is one of the largest buildings
ever built in the world.
It has a population of over 10,000 people,
and of course, this is a scale
that exceeds the comprehension
of many things and the scale
of typical architecture.
So we stopped work for a while
and sat down and cut 10,000 little sticks
and glued them onto a model,
just simply to confront ourselves
with what that quantity actually meant.
But of course, it&#39;s not a number,
it is the people, it is a community
that inhabits the building,
and in order to both comprehend
this, but also script this architecture,
we identified five characters,
hypothetical characters,
and we followed them throughout their day
in a life in this building,
thought of where they would meet,
what they would experience.
So it was a way to script and design
the building, but of course,
also to communicate its experiences.
This was part of an exhibition
with the Museum of Modern Art
in both New York and Beijing.
This is the main broadcast control room,
a technical installation so large,
it can broadcast over 200
channels simultaneously.
And this is how the building
stands in Beijing today.
Its first broadcast live
was the London Olympics 2012,
after it had been completed
from the outside for the Beijing Olympics.
And you can see at the very tip
of this 75-meter cantilever,
those three little circles.
And they&#39;re indeed part of a public loop
that goes through the building.
They&#39;re a piece of glass
that you can stand on
and watch the city pass by
below you in slow motion.
The building has become
part of everyday life in Beijing.
It is there.
It has also become a very popular backdrop
for wedding photography.

(Laughter)

But its most important moment
is maybe sill this one.
&quot;That&#39;s Beijing&quot; is similar to &quot;Time Out,&quot;
a magazine that broadcasts what
is happening in town during the week,
and suddenly you see the building
portrayed no longer as physical matter,
but actually as an urban actor,
as part of a series of personas
that define the life of the city.
So architecture suddenly
assumes the quality of a player,
of something that writes stories
and performs stories.
And I think that could be one
of its primary meanings
that we believe in.
But of course, there&#39;s another
story to this building.
It is the story of the people
that made it --
400 engineers and architects
that I was guiding
over almost a decade of collaborative work
that we spent together
in scripting this building,
in imagining its reality
and ultimately getting it built in China.
This is a residential development
in Singapore, large scale.
If we look at Singapore like most of Asia
and more and more of the world,
of course, it is dominated by the tower,
a typology that indeed creates
more isolation than connectedness,
and I wanted to ask, how
could we think about living,
not only in terms of the privacy
and individuality of ourselves
and our apartment,
but in an idea of a collective?
How could we think about creating
a communal environment
in which sharing things was as great
as having your own?
The typical answer to the question --
we had to design 1,040 apartments --

would have looked like this:
24-story height limit given
by the planning authorities,
12 towers with nothing
but residual in between --
a very tight system that,
although the tower isolates you,
it doesn&#39;t even give you privacy,
because you&#39;re so close to the next one,
that it is very questionable
what the qualities of this would be.
So I proposed to topple the towers,
throw the vertical into the horizontal
and stack them up,
and what looks a bit random from the side,
if you look from the viewpoint
of the helicopter,
you can see its organizational structure
is actually a hexagonal grid,
in which these horizontal
building blocks are stacked up
to create huge outdoor courtyards --
central spaces for the community,
programmed with a variety
of amenities and functions.
And you see that these courtyards
are not hermetically sealed spaces.
They&#39;re open, permeable;
they&#39;re interconnected.
We called the project &quot;The Interlace,&quot;
thinking that we interlace
and interconnect
the human beings and the spaces alike.
And the detailed quality
of everything we designed
was about animating the space
and giving the space to the inhabitants.
And, in fact, it was a system
where we would layer
primarily communal spaces,
stacked to more and more
individual and private spaces.
So we would open up a spectrum
between the collective and the individual.

A little piece of math:
if we count all the green
that we left on the ground,
minus the footprint of the buildings,
and we would add back
the green of all the terraces,
we have 112 percent green space,
so more nature than not
having built a building.
And of course this little piece of math
shows you that we are multiplying
the space available
to those who live there.
This is, in fact, the 13th floor
of one of these terraces.
So you see new datum planes,
new grounds planes for social activity.
We paid a lot of attention
to sustainability.
In the tropics, the sun is the most
important thing to pay attention to,
and, in fact, it is seeking
protection from the sun.
We first proved that all apartments
would have sufficient daylight
through the year.
We then went on to optimize
the glazing of the facades
to minimize the energy
consumption of the building.
But most importantly, we could prove
that through the geometry
of the building design,
the building itself would provide
sufficient shading to the courtyards
so that those would be usable
throughout the entire year.
We further placed water bodies
along the prevailing wind corridors,
so that evaporative cooling
would create microclimates
that, again, would enhance
the quality of those spaces
available for the inhabitants.
And it was the idea of creating
this variety of choices,
of freedom to think
where you would want to be,
where you would want to escape, maybe,
within the own complexity
of the complex in which you live.

But coming from Asia to Europe:
a building for a German
media company based in Berlin,
transitioning from the traditional
print media to the digital media.
And its CEO asked a few

very pertinent questions:
Why would anyone today
still want to go to the office,
because you can actually work anywhere?
And how could a digital identity
of a company be embodied
in a building?
We created not only an object,
but at the center of this object
we created a giant space,
and this space was about
the experience of a collective,
the experience of collaboration
and of togetherness.
Communication, interaction
as the center of a space
that in itself would float,
like what we call the collaborative cloud,
in the middle of the building,
surrounded by an envelope
of standard modular offices.
So with only a few steps
from your quiet work desk,
you could participate
in the giant collective experience
of the central space.
Finally, we come to London,
a project commissioned
by the London Legacy
Development Corporation
of the Mayor of London.
We were asked to undertake a study
and investigate the potential of a site
out in Stratford in the Olympic Park.
In the 19th century, Prince Albert
had created Albertopolis.
And Boris Johnson thought
of creating Olympicopolis.
The idea was to bring together
some of Britain&#39;s greatest institutions,
some international ones,
and to create a new system of synergies.
Prince Albert, as yet, created
Albertopolis in the 19th century,
thought of showcasing
all achievements of mankind,
bringing arts and science closer together.
And he built Exhibition Road,
a linear sequence of those institutions.
But of course, today&#39;s society
has moved on from there.
We no longer live in a world
in which everything
is as clearly delineated
or separated from each other.
We live in a world in which
boundaries start to blur
between the different domains,
and in which collaboration and interaction
becomes far more important
than keeping separations.
So we wanted to think
of a giant culture machine,
a building that would orchestrate
and animate the various domains,
but allow them to interact
and collaborate.
At the base of it is a very simple module,
a ring module.
It can function as a double-loaded
corridor, has daylight, has ventilation.
It can be glazed over
and turned into a giant
exhibitional performance space.
These modules were stacked together
with the idea that almost any
function could, over time,
occupy any of these modules.
So institutions could shrink or contract,
as, of course, the future of culture
is, in a way, the most uncertain of all.
This is how the building sits,
adjacent to the Aquatics Centre,
opposite the Olympic Stadium.
And you can see how
its cantilevering volumes
project out and engage the public space
and how its courtyards
animate the public inside.
The idea was to create a complex system
in which institutional entities
could maintain their own identity,
in which they would not
be subsumed in a singular volume.
Here&#39;s a scale comparison
to the Centre Pompidou in Paris.
It both shows the enormous scale
and potential of the project,

but also the difference:
here, it is a multiplicity
of a heterogeneous structure,
in which different entities can interact
without losing their own identity.

And it was this thought: to create
an organizational structure
that would allow for multiple
narratives to be scripted --
for those in the educational parts
that create and think culture;
for those that present
the visual arts, the dance;
and for the public to be
admitted into all of this
with a series of possible trajectories,
to script their own reading
of these narratives
and their own experience.
And I want to end on a project
that is very small,

in a way, very different:
a floating cinema
in the ocean of Thailand.
Friends of mine had founded
a film festival,
and I thought,
if we think of the stories
and narratives of movies,
we should also think of the narratives
of the people that watch them.
So I designed a small
modular floating platform,
based on the techniques
of local fishermen,
how they built their lobster
and fish farms.
We collaborated with the local community
and built, out of recycled
materials of their own,
this fantastical floating platform
that gently moved in the ocean
as we watched films
from the British film archive,
[1903] &quot;Alice in Wonderland,&quot; for example.
The most primordial
experiences of the audience
merged with the stories of the movies.
So I believe that architecture exceeds
the domain of physical matter,
of the built environment,
but is really about how
we want to live our lives,
how we script our own stories
and those of others.
Thank you.

(Applause)

