
We all make decisions every day; we want to know
what the right thing is to do -- in domains from the financial
to the gastronomic to the professional to the romantic.
And surely, if somebody could really tell us how to do
exactly the right thing at all possible times,
that would be a tremendous gift.
It turns out that, in fact, the world was given this gift in 1738
by a Dutch polymath named Daniel Bernoulli.
And what I want to talk to you about today is what that gift is,
and I also want to explain to you why it is
that it hasn&#39;t made a damn bit of difference.
Now, this is Bernoulli&#39;s gift. This is a direct quote.
And if it looks like Greek to you, it&#39;s because, well, it&#39;s Greek.
But the simple English translation -- much less precise,

but it captures the gist of what Bernoulli had to say -- was this:
The expected value of any of our actions --
that is, the goodness that we can count on getting --

is the product of two simple things:
the odds that this action will allow us to gain something,
and the value of that gain to us.
In a sense, what Bernoulli was saying is,
if we can estimate and multiply these two things,
we will always know precisely how we should behave.
Now, this simple equation, even for those of you
who don&#39;t like equations, is something that you&#39;re quite used to.

Here&#39;s an example: if I were to tell you, let&#39;s play
a little coin toss game, and I&#39;m going to flip a coin,
and if it comes up heads, I&#39;m going to pay you 10 dollars,
but you have to pay four dollars for the privilege of playing with me,
most of you would say, sure, I&#39;ll take that bet. Because you know
that the odds of you winning are one half, the gain if you do is 10 dollars,
that multiplies to five, and that&#39;s more
than I&#39;m charging you to play. So, the answer is, yes.
This is what statisticians technically call a damn fine bet.
Now, the idea is simple when we&#39;re applying it to coin tosses,
but in fact, it&#39;s not very simple in everyday life.
People are horrible at estimating both of these things,
and that&#39;s what I want to talk to you about today.
There are two kinds of errors people make when trying to decide
what the right thing is to do, and those are
errors in estimating the odds that they&#39;re going to succeed,
and errors in estimating the value of their own success.
Now, let me talk about the first one first.

Calculating odds would seem to be something rather easy:
there are six sides to a die, two sides to a coin, 52 cards in a deck.
You all know what the likelihood is of pulling the ace of spades
or of flipping a heads.
But as it turns out, this is not a very easy idea to apply
in everyday life. That&#39;s why Americans spend more --
I should say, lose more -- gambling
than on all other forms of entertainment combined.
The reason is, this isn&#39;t how people do odds.
The way people figure odds
requires that we first talk a bit about pigs.
Now, the question I&#39;m going to put to you is whether you think
there are more dogs or pigs on leashes
observed in any particular day in Oxford.
And of course, you all know that the answer is dogs.
And the way that you know that the answer is dogs is
you quickly reviewed in memory the times
you&#39;ve seen dogs and pigs on leashes.
It was very easy to remember seeing dogs,
not so easy to remember pigs. And each one of you assumed
that if dogs on leashes came more quickly to your mind,
then dogs on leashes are more probable.
That&#39;s not a bad rule of thumb, except when it is.
So, for example, here&#39;s a word puzzle.
Are there more four-letter English words
with R in the third place or R in the first place?
Well, you check memory very briefly, make a quick scan,
and it&#39;s awfully easy to say to yourself, Ring, Rang, Rung,

and very hard to say to yourself, Pare, Park: they come more slowly.
But in fact, there are many more words in the English language
with R in the third than the first place.
The reason words with R in the third place come slowly to your mind
isn&#39;t because they&#39;re improbable, unlikely or infrequent.
It&#39;s because the mind recalls words by their first letter.
You kind of shout out the sound, S -- and the word comes.
It&#39;s like the dictionary;
it&#39;s hard to look things up by the third letter.
So, this is an example of how this idea that
the quickness with which things come to mind
can give you a sense of their probability --
how this idea could lead you astray. It&#39;s not just puzzles, though.
For example, when Americans are asked to estimate the odds
that they will die in a variety of interesting ways --
these are estimates of number of deaths per year
per 200 million U.S. citizens.
And these are just ordinary people like yourselves who are asked
to guess how many people die from tornado, fireworks, asthma, drowning, etc.
Compare these to the actual numbers.
Now, you see a very interesting pattern here, which is first of all,
two things are vastly over-estimated, namely tornadoes and fireworks.

Two things are vastly underestimated:
dying by drowning and dying by asthma. Why?
When was the last time that you picked up a newspaper
and the headline was, &quot;Boy dies of Asthma?&quot;
It&#39;s not interesting because it&#39;s so common.
It&#39;s very easy for all of us to bring to mind instances
of news stories or newsreels where we&#39;ve seen
tornadoes devastating cities, or some poor schmuck
who&#39;s blown his hands off with a firework on the Fourth of July.
Drownings and asthma deaths don&#39;t get much coverage.
They don&#39;t come quickly to mind, and as a result,
we vastly underestimate them.
Indeed, this is kind of like the Sesame Street game
of &quot;Which thing doesn&#39;t belong?&quot; And you&#39;re right to say
it&#39;s the swimming pool that doesn&#39;t belong, because the swimming pool
is the only thing on this slide that&#39;s actually very dangerous.
The way that more of you are likely to die than the combination
of all three of the others that you see on the slide.
The lottery is an excellent example, of course -- an excellent test-case
of people&#39;s ability to compute probabilities.
And economists -- forgive me, for those of you who play the lottery --
but economists, at least among themselves, refer to the lottery
as a stupidity tax, because the odds of getting any payoff
by investing your money in a lottery ticket
are approximately equivalent to flushing the money
directly down the toilet -- which, by the way,
doesn&#39;t require that you actually go to the store and buy anything.
Why in the world would anybody ever play the lottery?
Well, there are many answers, but one answer surely is,
we see a lot of winners. Right? When this couple wins the lottery,
or Ed McMahon shows up at your door with this giant check --
how the hell do you cash things that size, I don&#39;t know.
We see this on TV; we read about it in the paper.
When was the last time that you saw extensive interviews
with everybody who lost?
Indeed, if we required that television stations run
a 30-second interview with each loser
every time they interview a winner, the 100 million losers
in the last lottery would require nine-and-a-half years
of your undivided attention just to watch them say,
&quot;Me? I lost.&quot; &quot;Me? I lost.&quot;
Now, if you watch nine-and-a-half years of television --
no sleep, no potty breaks -- and you saw loss after loss after loss,
and then at the end there&#39;s 30 seconds of, &quot;and I won,&quot;
the likelihood that you would play the lottery is very small.

Look, I can prove this to you: here&#39;s a little lottery.
There&#39;s 10 tickets in this lottery.
Nine of them have been sold to these individuals.
It costs you a dollar to buy the ticket and, if you win,
you get 20 bucks. Is this a good bet?
Well, Bernoulli tells us it is.
The expected value of this lottery is two dollars;
this is a lottery in which you should invest your money.
And most people say, &quot;OK, I&#39;ll play.&quot;

Now, a slightly different version of this lottery:
imagine that the nine tickets are all owned
by one fat guy named Leroy.
Leroy has nine tickets; there&#39;s one left.
Do you want it? Most people won&#39;t play this lottery.
Now, you can see the odds of winning haven&#39;t changed,
but it&#39;s now fantastically easy to imagine who&#39;s going to win.
It&#39;s easy to see Leroy getting the check, right?
You can&#39;t say to yourself, &quot;I&#39;m as likely to win as anybody,&quot;
because you&#39;re not as likely to win as Leroy.
The fact that all those tickets are owned by one guy
changes your decision to play,
even though it does nothing whatsoever to the odds.
Now, estimating odds, as difficult as it may seem, is a piece of cake

compared to trying to estimate value:
trying to say what something is worth, how much we&#39;ll enjoy it,
how much pleasure it will give us.
I want to talk now about errors in value.
How much is this Big Mac worth? Is it worth 25 dollars?
Most of you have the intuition that it&#39;s not --
you wouldn&#39;t pay that for it.
But in fact, to decide whether a Big Mac is worth 25 dollars requires

that you ask one, and only one question, which is:
What else can I do with 25 dollars?
If you&#39;ve ever gotten on one of those long-haul flights to Australia
and realized that they&#39;re not going to serve you any food,
but somebody in the row in front of you has just opened
the McDonald&#39;s bag, and the smell of golden arches
is wafting over the seat, you think,
I can&#39;t do anything else with this 25 dollars for 16 hours.
I can&#39;t even set it on fire -- they took my cigarette lighter!
Suddenly, 25 dollars for a Big Mac might be a good deal.
On the other hand, if you&#39;re visiting an underdeveloped country,
and 25 dollars buys you a gourmet meal, it&#39;s exorbitant for a Big Mac.
Why were you all sure that the answer to the question was no,
before I&#39;d even told you anything about the context?
Because most of you compared the price of this Big Mac
to the price you&#39;re used to paying. Rather than asking,
&quot;What else can I do with my money,&quot; comparing this investment
to other possible investments, you compared to the past.
And this is a systematic error people make.
What you knew is, you paid three dollars in the past; 25 is outrageous.
This is an error, and I can prove it to you by showing
the kinds of irrationalities to which it leads.
For example, this is, of course,
one of the most delicious tricks in marketing,
is to say something used to be higher,
and suddenly it seems like a very good deal.

When people are asked about these two different jobs:
a job where you make 60K, then 50K, then 40K,
a job where you&#39;re getting a salary cut each year,
and one in which you&#39;re getting a salary increase,
people like the second job better than the first, despite the fact
they&#39;re all told they make much less money. Why?
Because they had the sense that declining wages are worse
than rising wages, even when the total amount of wages is higher
in the declining period. Here&#39;s another nice example.
Here&#39;s a $2,000 Hawaiian vacation package; it&#39;s now on sale for 1,600.
Assuming you wanted to go to Hawaii, would you buy this package?

Most people say they would. Here&#39;s a slightly different story:
$2,000 Hawaiian vacation package is now on sale for 700 dollars,
so you decide to mull it over for a week.
By the time you get to the ticket agency, the best fares are gone --
the package now costs 1,500. Would you buy it? Most people say, no.
Why? Because it used to cost 700, and there&#39;s no way I&#39;m paying 1,500
for something that was 700 last week.
This tendency to compare to the past
is causing people to pass up the better deal. In other words,
a good deal that used to be a great deal is not nearly as good
as an awful deal that was once a horrible deal.
Here&#39;s another example of how comparing to the past
can befuddle our decisions.
Imagine that you&#39;re going to the theater.
You&#39;re on your way to the theater.
In your wallet you have a ticket, for which you paid 20 dollars.
You also have a 20-dollar bill.
When you arrive at the theater,
you discover that somewhere along the way you&#39;ve lost the ticket.
Would you spend your remaining money on replacing it?
Most people answer, no.
Now, let&#39;s just change one thing in this scenario.
You&#39;re on your way to the theater,
and in your wallet you have two 20-dollar bills.
When you arrive you discover you&#39;ve lost one of them.
Would you spend your remaining 20 dollars on a ticket?
Well, of course, I went to the theater to see the play.
What does the loss of 20 dollars along the way have to do?
Now, just in case you&#39;re not getting it,
here&#39;s a schematic of what happened, OK?

(Laughter)

Along the way, you lost something.
In both cases, it was a piece of paper.
In one case, it had a U.S. president on it; in the other case it didn&#39;t.
What the hell difference should it make?
The difference is that when you lost the ticket you say to yourself,
I&#39;m not paying twice for the same thing.
You compare the cost of the play now -- 40 dollars --
to the cost that it used to have -- 20 dollars -- and you say it&#39;s a bad deal.
Comparing with the past causes many of the problems
that behavioral economists and psychologists identify
in people&#39;s attempts to assign value.
But even when we compare with the possible, instead of the past,
we still make certain kinds of mistakes.
And I&#39;m going to show you one or two of them.

One of the things we know about comparison:
that when we compare one thing to the other, it changes its value.
So in 1992, this fellow, George Bush, for those of us who were
kind of on the liberal side of the political spectrum,
didn&#39;t seem like such a great guy.
Suddenly, we&#39;re almost longing for him to return.

(Laughter)

The comparison changes how we evaluate him.
Now, retailers knew this long before anybody else did, of course,
and they use this wisdom to help you --
spare you the undue burden of money.
And so a retailer, if you were to go into a wine shop
and you had to buy a bottle of wine,
and you see them here for eight, 27 and 33 dollars, what would you do?
Most people don&#39;t want the most expensive,
they don&#39;t want the least expensive.
So, they will opt for the item in the middle.
If you&#39;re a smart retailer, then, you will put a very expensive item
that nobody will ever buy on the shelf,
because suddenly the $33 wine doesn&#39;t look as expensive in comparison.

So I&#39;m telling you something you already knew:
namely, that comparison changes the value of things.

Here&#39;s why that&#39;s a problem:
the problem is that when you get that $33 bottle of wine home,
it won&#39;t matter what it used to be sitting on the shelf next to.
The comparisons we make when we are appraising value,
where we&#39;re trying to estimate how much we&#39;ll like things,
are not the same comparisons we&#39;ll be making when we consume them.
This problem of shifting comparisons can bedevil
our attempts to make rational decisions.
Let me just give you an example.
I have to show you something from my own lab, so let me sneak this in.
These are subjects coming to an experiment to be asked

the simplest of all questions:
How much will you enjoy eating potato chips one minute from now?
They&#39;re sitting in a room with potato chips in front of them.
For some of the subjects, sitting in the far corner of a room
is a box of Godiva chocolates, and for others is a can of Spam.
In fact, these items that are sitting in the room change
how much the subjects think they&#39;re going to enjoy the potato chips.
Namely, those who are looking at Spam
think potato chips are going to be quite tasty;
those who are looking at Godiva chocolate
think they won&#39;t be nearly so tasty.
Of course, what happens when they eat the potato chips?
Well, look, you didn&#39;t need a psychologist to tell you that
when you have a mouthful of greasy, salty, crispy, delicious snacks,
what&#39;s sitting in the corner of the room
makes not a damn bit of difference to your gustatory experience.
Nonetheless, their predictions are perverted by a comparison
that then does not carry through and change their experience.
You&#39;ve all experienced this yourself, even if you&#39;ve never come

into our lab to eat potato chips. So here&#39;s a question:
You want to buy a car stereo.
The dealer near your house sells this particular stereo for 200 dollars,
but if you drive across town, you can get it for 100 bucks.
So would you drive to get 50 percent off, saving 100 dollars?
Most people say they would.
They can&#39;t imagine buying it for twice the price
when, with one trip across town, they can get it for half off.
Now, let&#39;s imagine instead you wanted to buy a car that had a stereo,
and the dealer near your house had it for 31,000.
But if you drove across town, you could get it for 30,900.
Would you drive to get it? At this point, 0.003 savings -- the 100 dollars.
Most people say, no, I&#39;m going to schlep across town
to save 100 bucks on the purchase of a car?
This kind of thinking drives economists crazy, and it should.
Because this 100 dollars that you save -- hello! --
doesn&#39;t know where it came from.
It doesn&#39;t know what you saved it on.
When you go to buy groceries with it, it doesn&#39;t go,
I&#39;m the money saved on the car stereo, or,
I&#39;m the dumb money saved on the car. It&#39;s money.
And if a drive across town is worth 100 bucks, it&#39;s worth 100 bucks
no matter what you&#39;re saving it on. People don&#39;t think that way.
That&#39;s why they don&#39;t know whether their mutual fund manager
is taking 0.1 percent or 0.15 percent of their investment,
but they clip coupons to save one dollar off of toothpaste.
Now, you can see, this is the problem of shifting comparisons,
because what you&#39;re doing is, you&#39;re comparing the 100 bucks
to the purchase that you&#39;re making,
but when you go to spend that money you won&#39;t be making that comparison.
You&#39;ve all had this experience.
If you&#39;re an American, for example, you&#39;ve probably traveled in France.
And at some point you may have met a couple
from your own hometown, and you thought,
&quot;Oh, my God, these people are so warm. They&#39;re so nice to me.
I mean, compared to all these people who hate me
when I try to speak their language and hate me more when I don&#39;t,
these people are just wonderful.&quot; And so you tour France with them,
and then you get home and you invite them over for dinner,
and what do you find?
Compared to your regular friends,
they are boring and dull, right? Because in this new context,
the comparison is very, very different. In fact, you find yourself
disliking them enough almost to qualify for French citizenship.
Now, you have exactly the same problem when you shop for a stereo.
You go to the stereo store, you see two sets of speakers --
these big, boxy, monoliths, and these little, sleek speakers,

and you play them, and you go, you know, I do hear a difference:
the big ones sound a little better.
And so you buy them, and you bring them home,
and you entirely violate the décor of your house.
And the problem, of course, is that this comparison you made in the store
is a comparison you&#39;ll never make again.
What are the odds that years later you&#39;ll turn on the stereo and go,
&quot;Sounds so much better than those little ones,&quot;
which you can&#39;t even remember hearing.
The problem of shifting comparisons is even more difficult
when these choices are arrayed over time.
People have a lot of trouble making decisions
about things that will happen at different points in time.
And what psychologists and behavioral economists have discovered
is that by and large people use two simple rules.
So let me give you one very easy problem, a second very easy problem
and then a third, hard, problem.

Here&#39;s the first easy problem:
You can have 60 dollars now or 50 dollars now. Which would you prefer?
This is what we call a one-item IQ test, OK?
All of us, I hope, prefer more money, and the reason is,
we believe more is better than less.

Here&#39;s the second problem:
You can have 60 dollars today or 60 dollars in a month. Which would you prefer?
Again, an easy decision,
because we all know that now is better than later.
What&#39;s hard in our decision-making is when these two rules conflict.
For example, when you&#39;re offered 50 dollars now or 60 dollars in a month.
This typifies a lot of situations in life in which you will gain
by waiting, but you have to be patient.
What do we know? What do people do in these kinds of situations?
Well, by and large people are enormously impatient.
That is, they require interest rates in the hundred
or thousands of percents in order to delay gratification
and wait until next month for the extra 10 dollars.
Maybe that isn&#39;t so remarkable, but what is remarkable is
how easy it is to make this impatience go away by simply changing
when the delivery of these monetary units will happen.
Imagine that you can have 50 dollars in a year -- that&#39;s 12 months --
or 60 dollars in 13 months.
What do we find now?

People are gladly willing to wait: as long as they&#39;re waiting 12,
they might as well wait 13.
What makes this dynamic inconsistency happen?
Comparison. Troubling comparison. Let me show you.
This is just a graph showing the results that I just suggested
you would show if I gave you time to respond, which is,
people find that the subjective value of 50 is higher
than the subjective value of 60 when they&#39;ll be delivered in now
or one month, respectively -- a 30-day delay --
but they show the reverse pattern when you push the entire decision
off into the future a year.
Now, why in the world do you get this pattern of results?
These guys can tell us.
What you see here are two lads,

one of them larger than the other: the fireman and the fiddler.
They are going to recede towards the vanishing point in the horizon,
and I want you to notice two things.
At no point will the fireman look taller than the fiddler. No point.
However, the difference between them seems to be getting smaller.
First it&#39;s an inch in your view, then it&#39;s a quarter-inch,
then a half-inch, and then finally they go off the edge of the earth.
Here are the results of what I just showed you.
This is the subjective height --
the height you saw of these guys at various points.
And I want you to see that two things are true.
One, the farther away they are, the smaller they look;
and two, the fireman is always bigger than the fiddler.
But watch what happens when we make some of them disappear. Right.
At a very close distance, the fiddler looks taller than the fireman,
but at a far distance
their normal, their true, relations are preserved.
As Plato said, what space is to size, time is to value.

These are the results of the hard problem I gave you:
60 now or 50 in a month?
And these are subjective values,
and what you can see is, our two rules are preserved.

People always think more is better than less:
60 is always better than 50,

and they always think now is better than later:
the bars on this side are higher than the bars on this side.
Watch what happens when we drop some out.
Suddenly we have the dynamic inconsistency that puzzled us.
We have the tendency for people to go for 50 dollars now
over waiting a month, but not if that decision is far in the future.
Notice something interesting that this implies -- namely, that
when people get to the future, they will change their minds.
That is, as that month 12 approaches, you will say,
what was I thinking, waiting an extra month for 60 dollars?
I&#39;ll take the 50 dollars now.

Well, the question with which I&#39;d like to end is this:
If we&#39;re so damn stupid, how did we get to the moon?
Because I could go on for about two hours with evidence
of people&#39;s inability to estimate odds and inability to estimate value.
The answer to this question, I think, is an answer you&#39;ve already heard

in some of the talks, and I dare say you will hear again:
namely, that our brains were evolved for a very different world
than the one in which we are living.
They were evolved for a world
in which people lived in very small groups,
rarely met anybody who was terribly different from themselves,
had rather short lives in which there were few choices
and the highest priority was to eat and mate today.
Bernoulli&#39;s gift, Bernoulli&#39;s little formula, allows us, it tells us
how we should think in a world for which nature never designed us.
That explains why we are so bad at using it, but it also explains
why it is so terribly important that we become good, fast.
We are the only species on this planet
that has ever held its own fate in its hands.
We have no significant predators,
we&#39;re the masters of our physical environment;
the things that normally cause species to become extinct
are no longer any threat to us.
The only thing -- the only thing -- that can destroy us and doom us
are our own decisions.
If we&#39;re not here in 10,000 years, it&#39;s going to be because
we could not take advantage of the gift given to us
by a young Dutch fellow in 1738,
because we underestimated the odds of our future pains
and overestimated the value of our present pleasures.
Thank you.

(Applause)


Chris Anderson: That was remarkable.
We have time for some questions for Dan Gilbert. One and two.

Bill Lyell: Would you say that this mechanism
is in part how terrorism actually works to frighten us,
and is there some way that we could counteract that?

Dan Gilbert: I actually was consulting recently
with the Department of Homeland Security, which generally believes
that American security dollars should go to making borders safer.
I tried to point out to them that terrorism was a name
based on people&#39;s psychological reaction to a set of events,
and that if they were concerned about terrorism they might ask
what causes terror and how can we stop people from being terrified,
rather than -- not rather than, but in addition to
stopping the atrocities that we&#39;re all concerned about.
Surely the kinds of play that at least American media give to --
and forgive me, but in raw numbers these are very tiny accidents.
We already know, for example, in the United States,
more people have died as a result of not taking airplanes --
because they were scared -- and driving on highways,
than were killed in 9/11. OK?
If I told you that there was a plague
that was going to kill 15,000 Americans next year,
you might be alarmed if you didn&#39;t find out it was the flu.
These are small-scale accidents, and we should be wondering
whether they should get the kind of play,
the kind of coverage, that they do.
Surely that causes people to overestimate the likelihood
that they&#39;ll be hurt in these various ways,
and gives power to the very people who want to frighten us.

CA: Dan, I&#39;d like to hear more on this. So, you&#39;re saying
that our response to terror is, I mean, it&#39;s a form of mental bug?
Talk more about it.

DG: It&#39;s out-sized. I mean, look.
If Australia disappears tomorrow,
terror is probably the right response.
That&#39;s an awful large lot of very nice people. On the other hand,
when a bus blows up and 30 people are killed,
more people than that were killed
by not using their seatbelts in the same country.
Is terror the right response?

CA: What causes the bug? Is it the drama of the event --
that it&#39;s so spectacular?
Is it the fact that it&#39;s an intentional attack by, quote, outsiders?
What is it?

DG: Yes. It&#39;s a number of things, and you hit on several of them.
First, it&#39;s a human agent trying to kill us --
it&#39;s not a tree falling on us by accident.
Second, these are enemies who may want to strike and hurt us again.
People are being killed for no reason instead of good reason --
as if there&#39;s good reason, but sometimes people think there are.
So there are a number of things that together
make this seem like a fantastic event, but let&#39;s not play down
the fact that newspapers sell when people see something in it
they want to read. So there&#39;s a large role here played by the media,
who want these things to be
as spectacular as they possibly can.

CA: I mean, what would it take to persuade our culture to downplay it?

DG: Well, go to Israel. You know,
go to Israel. And a mall blows up,
and then everybody&#39;s unhappy about it, and an hour-and-a-half later --
at least when I was there, and I was 150 feet from the mall
when it blew up -- I went back to my hotel
and the wedding that was planned was still going on.
And as the Israeli mother said,
she said, &quot;We never let them win by stopping weddings.&quot;
I mean, this is a society that has learned --
and there are others too -- that has learned to live
with a certain amount of terrorism and not be quite as upset by it,
shall I say, as those of us who have not had many terror attacks.

CA: But is there a rational fear that actually,
the reason we&#39;re frightened about this is because we think that
the Big One is to come?

DG: Yes, of course. So, if we knew that this was the worst attack
there would ever be, there might be more and more buses of 30 people --
we would probably not be nearly so frightened.
I don&#39;t want to say -- please, I&#39;m going to get quoted somewhere
as saying, &quot;Terrorism is fine and we shouldn&#39;t be so distressed.&quot;
That&#39;s not my point at all.
What I&#39;m saying is that, surely, rationally,
our distress about things that happen, about threats,
should be roughly proportional to the size of those threats
and threats to come.
I think in the case of terrorism, it isn&#39;t.
And many of the things we&#39;ve heard about from our speakers today --
how many people do you know got up and said,
Poverty! I can&#39;t believe what poverty is doing to us.
People get up in the morning; they don&#39;t care about poverty.
It&#39;s not making headlines, it&#39;s not making news, it&#39;s not flashy.
There are no guns going off.
I mean, if you had to solve one of these problems, Chris,
which would you solve? Terrorism or poverty?

(Laughter)


(Applause)

That&#39;s a tough one.

CA: There&#39;s no question.
Poverty, by an order of magnitude, a huge order of magnitude,
unless someone can show that there&#39;s, you know,
terrorists with a nuke are really likely to come.
The latest I&#39;ve read, seen, thought
is that it&#39;s incredibly hard for them to do that.
If that turns out to be wrong, we all look silly,
but with poverty it&#39;s a bit --

DG: Even if that were true, still more people die from poverty.

CA: We&#39;ve evolved to get all excited
about these dramatic attacks. Is that because in the past,
in the ancient past, we just didn&#39;t understand things like disease
and systems that cause poverty and so forth,
and so it made no sense for us as a species to put any energy
into worrying about those things?
People died; so be it.
But if you got attacked, that was something you could do something about.
And so we evolved these responses.
Is that what happened?

DG: Well, you know, the people who are most skeptical
about leaping to evolutionary explanations for everything
are the evolutionary psychologists themselves.
My guess is that there&#39;s nothing quite that specific
in our evolutionary past. But rather, if you&#39;re looking for
an evolutionary explanation, you might say
that most organisms are neo-phobic -- that is, they&#39;re a little scared
of stuff that&#39;s new and different.
And there&#39;s a good reason to be,
because old stuff didn&#39;t eat you. Right?
Any animal you see that you&#39;ve seen before is less likely
to be a predator than one that you&#39;ve never seen before.
So, you know, when a school bus is blown up and we&#39;ve never seen this before,
our general tendency is to orient towards
that which is new and novel is activated.
I don&#39;t think it&#39;s quite as specific a mechanism
as the one you alluded to, but maybe a more fundamental one underlying it.

Jay Walker: You know, economists love to talk about
the stupidity of people who buy lottery tickets. But I suspect
you&#39;re making the exact same error you&#39;re accusing those people of,
which is the error of value.
I know, because I&#39;ve interviewed
about 1,000 lottery buyers over the years.
It turns out that the value of buying a lottery ticket is not winning.
That&#39;s what you think it is. All right?
The average lottery buyer buys about 150 tickets a year,
so the buyer knows full well that he or she is going to lose,
and yet she buys 150 tickets a year. Why is that?
It&#39;s not because she is stupid or he is stupid.
It&#39;s because the anticipation of possibly winning
releases serotonin in the brain, and actually provides a good feeling
until the drawing indicates you&#39;ve lost.
Or, to put it another way, for the dollar investment,
you can have a much better feeling than flushing the money
down the toilet, which you cannot have a good feeling from.
Now, economists tend to --

(Applause)

-- economists tend to view the world

through their own lenses, which is:
this is just a bunch of stupid people.
And as a result, many people look at economists as stupid people.
And so fundamentally, the reason we got to the moon is,
we didn&#39;t listen to the economists. Thank you very much.

(Applause)


DG: Well, no, it&#39;s a great point. It remains to be seen
whether the joy of anticipation is exactly equaled
by the amount of disappointment after the lottery. Because remember,
people who didn&#39;t buy tickets don&#39;t feel awful the next day either,
even though they don&#39;t feel great during the drawing.
I would disagree that people know they&#39;re not going to win.
I think they think it&#39;s unlikely, but it could happen,
which is why they prefer that to the flushing.

But certainly I see your point: that there can be
some utility to buying a lottery ticket other than winning.
Now, I think there&#39;s many good reasons not to listen to economists.
That isn&#39;t one of them, for me, but there&#39;s many others.

CA: Last question.

Aubrey de Grey: My name&#39;s Aubrey de Grey, from Cambridge.
I work on the thing that kills more people than anything else kills --
I work on aging -- and I&#39;m interested in doing something about it,
as we&#39;ll all hear tomorrow.
I very much resonate with what you&#39;re saying,
because it seems to me that the problem
with getting people interested in doing anything about aging
is that by the time aging is about to kill you it looks like cancer
or heart disease or whatever. Do you have any advice?

(Laughter)


DG: For you or for them?

AdG: In persuading them.

DG: Ah, for you in persuading them.
Well, it&#39;s notoriously difficult to get people to be farsighted.
But one thing that psychologists have tried that seems to work
is to get people to imagine the future more vividly.
One of the problems with making decisions about the far future
and the near future is that we imagine the near future
much more vividly than the far future.
To the extent that you can equalize the amount of detail
that people put into the mental representations
of near and far future, people begin to make decisions
about the two in the same way.
So, would you like to have an extra 100,000 dollars when you&#39;re 65
is a question that&#39;s very different than,

imagine who you&#39;ll be when you&#39;re 65: will you be living,
what will you look like, how much hair will you have,
who will you be living with.
Once we have all the details of that imaginary scenario,
suddenly we feel like it might be important to save
so that that guy has a little retirement money.
But these are tricks around the margins.
I think in general you&#39;re battling a very fundamental human tendency,
which is to say, &quot;I&#39;m here today,
and so now is more important than later.&quot;

CA: Dan, thank you. Members of the audience,
that was a fantastic session. Thank you.

(Applause)

