
A few years ago,
with my colleague, Emmanuelle Charpentier,
I invented a new technology
for editing genomes.
It&#39;s called CRISPR-Cas9.
The CRISPR technology allows
scientists to make changes
to the DNA in cells
that could allow us
to cure genetic disease.
You might be interested to know
that the CRISPR technology came about
through a basic research project
that was aimed at discovering
how bacteria fight viral infections.
Bacteria have to deal with viruses
in their environment,
and we can think about a viral infection
like a ticking time bomb --
a bacterium has only a few minutes
to defuse the bomb
before it gets destroyed.
So, many bacteria have in their cells
an adaptive immune system called CRISPR,
that allows them to detect
viral DNA and destroy it.
Part of the CRISPR system
is a protein called Cas9,
that&#39;s able to seek out, cut
and eventually degrade viral DNA
in a specific way.
And it was through our research
to understand the activity
of this protein, Cas9,
that we realized that we could
harness its function
as a genetic engineering technology --
a way for scientists to delete or insert
specific bits of DNA into cells
with incredible precision --
that would offer opportunities
to do things that really haven&#39;t
been possible in the past.
The CRISPR technology
has already been used
to change the DNA in the cells
of mice and monkeys,
other organisms as well.
Chinese scientists showed recently
that they could even use
the CRISPR technology
to change genes in human embryos.
And scientists in Philadelphia showed
they could use CRISPR
to remove the DNA
of an integrated HIV virus
from infected human cells.
The opportunity to do this kind
of genome editing
also raises various ethical issues
that we have to consider,
because this technology can be employed
not only in adult cells,
but also in the embryos of organisms,
including our own species.
And so, together with my colleagues,
I&#39;ve called for a global conversation
about the technology that I co-invented,
so that we can consider all of the ethical
and societal implications
of a technology like this.
What I want to do now is tell you
what the CRISPR technology is,
what it can do,
where we are today
and why I think we need to take
a prudent path forward
in the way that we employ this technology.
When viruses infect a cell,
they inject their DNA.
And in a bacterium,
the CRISPR system allows that DNA
to be plucked out of the virus,
and inserted in little bits
into the chromosome --
the DNA of the bacterium.
And these integrated bits of viral DNA
get inserted at a site called CRISPR.
CRISPR stands for clustered regularly
interspaced short palindromic repeats.

(Laughter)

A big mouthful -- you can see why
we use the acronym CRISPR.
It&#39;s a mechanism that allows cells
to record, over time,
the viruses they have been exposed to.
And importantly, those bits of DNA
are passed on to the cells&#39; progeny,
so cells are protected from viruses
not only in one generation,
but over many generations of cells.
This allows the cells
to keep a record of infection,
and as my colleague,
Blake Wiedenheft, likes to say,
the CRISPR locus is effectively
a genetic vaccination card in cells.
Once those bits of DNA have been inserted
into the bacterial chromosome,
the cell then makes a little copy
of a molecule called RNA,
which is orange in this picture,
that is an exact replicate
of the viral DNA.
RNA is a chemical cousin of DNA,
and it allows interaction
with DNA molecules
that have a matching sequence.
So those little bits of RNA
from the CRISPR locus
associate -- they bind --
to protein called Cas9,
which is white in the picture,
and form a complex that functions
like a sentinel in the cell.
It searches through all
of the DNA in the cell,
to find sites that match
the sequences in the bound RNAs.
And when those sites are found --
as you can see here,
the blue molecule is DNA --
this complex associates with that DNA
and allows the Cas9 cleaver
to cut up the viral DNA.
It makes a very precise break.
So we can think of the Cas9 RNA
sentinel complex
like a pair of scissors
that can cut DNA --
it makes a double-stranded break
in the DNA helix.
And importantly,
this complex is programmable,
so it can be programmed to recognize
particular DNA sequences,
and make a break in the DNA at that site.
As I&#39;m going to tell you now,
we recognized that that activity
could be harnessed for genome engineering,
to allow cells to make
a very precise change to the DNA
at the site where
this break was introduced.
That&#39;s sort of analogous
to the way that we use
a word-processing program
to fix a typo in a document.
The reason we envisioned using
the CRISPR system for genome engineering
is because cells have the ability
to detect broken DNA
and repair it.
So when a plant or an animal cell detects
a double-stranded break in its DNA,
it can fix that break,
either by pasting together
the ends of the broken DNA
with a little, tiny change
in the sequence of that position,
or it can repair the break by integrating
a new piece of DNA at the site of the cut.
So if we have a way to introduce
double-stranded breaks into DNA
at precise places,
we can trigger cells
to repair those breaks,
by either the disruption or incorporation
of new genetic information.
So if we were able to program
the CRISPR technology
to make a break in DNA
at the position at or near a mutation
causing cystic fibrosis, for example,
we could trigger cells
to repair that mutation.
Genome engineering is actually not new,
it&#39;s been in development since the 1970s.
We&#39;ve had technologies for sequencing DNA,
for copying DNA,
and even for manipulating DNA.
And these technologies
were very promising,
but the problem was
that they were either inefficient,
or they were difficult enough to use
that most scientists had not adopted them
for use in their own laboratories,
or certainly for many
clinical applications.
So, the opportunity to take a technology
like CRISPR and utilize it has appeal,
because of its relative simplicity.
We can think of older
genome engineering technologies
as similar to having
to rewire your computer
each time you want to run
a new piece of software,
whereas the CRISPR technology
is like software for the genome,
we can program it easily,
using these little bits of RNA.
So once a double-stranded
break is made in DNA,
we can induce repair,
and thereby potentially achieve
astounding things,
like being able to correct mutations
that cause sickle cell anemia
or cause Huntington&#39;s Disease.
I actually think that the first
applications of the CRISPR technology
are going to happen in the blood,
where it&#39;s relatively easier
to deliver this tool into cells,
compared to solid tissues.
Right now, a lot of the work
that&#39;s going on
applies to animal models
of human disease, such as mice.
The technology is being used to make
very precise changes
that allow us to study the way
that these changes in the cell&#39;s DNA
affect either a tissue or,
in this case, an entire organism.
Now in this example,
the CRISPR technology
was used to disrupt a gene
by making a tiny change in the DNA
in a gene that is responsible
for the black coat color of these mice.
Imagine that these white mice
differ from their pigmented litter-mates
by just a tiny change at one gene
in the entire genome,
and they&#39;re otherwise completely normal.
And when we sequence the DNA
from these animals,
we find that the change in the DNA
has occurred at exactly the place
where we induced it,
using the CRISPR technology.
Additional experiments
are going on in other animals
that are useful for creating models
for human disease,
such as monkeys.
And here we find
that we can use these systems
to test the application of this technology
in particular tissues,
for example, figuring out how to deliver
the CRISPR tool into cells.
We also want to understand better
how to control the way
that DNA is repaired after it&#39;s cut,
and also to figure out how to control
and limit any kind of off-target,
or unintended effects
of using the technology.
I think that we will see
clinical application of this technology,
certainly in adults,
within the next 10 years.
I think that it&#39;s likely
that we will see clinical trials
and possibly even approved
therapies within that time,
which is a very exciting thing
to think about.
And because of the excitement
around this technology,
there&#39;s a lot of interest
in start-up companies
that have been founded
to commercialize the CRISPR technology,
and lots of venture capitalists
that have been investing
in these companies.
But we have to also consider
that the CRISPR technology can be used
for things like enhancement.
Imagine that we could try
to engineer humans
that have enhanced properties,
such as stronger bones,
or less susceptibility
to cardiovascular disease
or even to have properties
that we would consider maybe
to be desirable,
like a different eye color
or to be taller, things like that.
&quot;Designer humans,&quot; if you will.
Right now, the genetic information
to understand what types of genes
would give rise to these traits
is mostly not known.
But it&#39;s important to know
that the CRISPR technology gives us a tool
to make such changes,
once that knowledge becomes available.
This raises a number of ethical questions
that we have to carefully consider,
and this is why I and my colleagues
have called for a global pause
in any clinical application
of the CRISPR technology in human embryos,
to give us time
to really consider all of the various
implications of doing so.
And actually, there is an important
precedent for such a pause
from the 1970s,
when scientists got together
to call for a moratorium
on the use of molecular cloning,
until the safety of that technology
could be tested carefully and validated.
So, genome-engineered humans
are not with us yet,
but this is no longer science fiction.
Genome-engineered animals and plants
are happening right now.
And this puts in front of all of us
a huge responsibility,
to consider carefully
both the unintended consequences
as well as the intended impacts
of a scientific breakthrough.
Thank you.

(Applause)

(Applause ends)

Bruno Giussani: Jennifer, this is
a technology with huge consequences,
as you pointed out.
Your attitude about asking for a pause
or a moratorium or a quarantine
is incredibly responsible.
There are, of course,
the therapeutic results of this,
but then there are the un-therapeutic ones
and they seem to be the ones
gaining traction,
particularly in the media.
This is one of the latest issues
of The Economist -- &quot;Editing humanity.&quot;
It&#39;s all about genetic enhancement,
it&#39;s not about therapeutics.
What kind of reactions
did you get back in March
from your colleagues in the science world,
when you asked or suggested
that we should actually pause this
for a moment and think about it?

Jennifer Doudna: My colleagues
were actually, I think, delighted
to have the opportunity
to discuss this openly.
It&#39;s interesting that as I talk to people,
my scientific colleagues
as well as others,
there&#39;s a wide variety
of viewpoints about this.
So clearly it&#39;s a topic that needs
careful consideration and discussion.

BG: There&#39;s a big meeting
happening in December
that you and your colleagues are calling,
together with the National Academy
of Sciences and others,
what do you hope will come
out of the meeting, practically?

JD: Well, I hope that we can air the views
of many different individuals
and stakeholders
who want to think about how to use
this technology responsibly.
It may not be possible to come up with
a consensus point of view,
but I think we should at least understand
what all the issues are as we go forward.

BG: Now, colleagues of yours,
like George Church,
for example, at Harvard,
they say, &quot;Yeah, ethical issues basically
are just a question of safety.
We test and test and test again,
in animals and in labs,
and then once we feel it&#39;s safe enough,
we move on to humans.&quot;
So that&#39;s kind of the other
school of thought,
that we should actually use
this opportunity and really go for it.
Is there a possible split happening
in the science community about this?
I mean, are we going to see
some people holding back
because they have ethical concerns,
and some others just going forward
because some countries under-regulate
or don&#39;t regulate at all?

JD: Well, I think with any new technology,
especially something like this,
there are going to be
a variety of viewpoints,
and I think that&#39;s
perfectly understandable.
I think that in the end,
this technology will be used
for human genome engineering,
but I think to do that without careful
consideration and discussion
of the risks and potential complications
would not be responsible.

BG: There are a lot of technologies
and other fields of science
that are developing exponentially,
pretty much like yours.
I&#39;m thinking about artificial
intelligence, autonomous robots and so on.
No one seems --
aside from autonomous warfare robots --
nobody seems to have launched
a similar discussion in those fields,
in calling for a moratorium.
Do you think that your discussion may
serve as a blueprint for other fields?

JD: Well, I think it&#39;s hard for scientists
to get out of the laboratory.
Speaking for myself,
it&#39;s a little bit
uncomfortable to do that.
But I do think that being involved
in the genesis of this
really puts me and my colleagues
in a position of responsibility.
And I would say that I certainly hope
that other technologies
will be considered in the same way,
just as we would want to consider
something that could have implications
in other fields besides biology.

BG: Jennifer, thanks for coming to TED.

JD: Thank you.

(Applause)

